@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: bbs_thread_ui.c,v 1.4 2003/05/11 18:17:54 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,8 @@
 #include "ochusha.h"
 #include "ochusha_ui.h"
 
+#include "ochusha_thread_2ch.h"
+
 #include "bbs_thread_ui.h"
 #include "bbs_thread_view.h"
 #include "boardlist_ui.h"
@@ -52,32 +54,37 @@ static void link_popup_menu_callback(gpointer data, guint action,
 				     GtkWidget *widget);
 static void link_popup_menu_destructed_cb(gpointer data);
 static gboolean link_mouse_over_cb(BBSThreadView *view, GdkEventMotion *event,
-				   BBSThread *thread, const gchar *link,
+				   OchushaBBSThread *thread, const gchar *link,
 				   OchushaApplication *application);
 static gboolean link_mouse_out_cb(BBSThreadView *view, GdkEventMotion *event,
-				  BBSThread *thread, const gchar *link,
+				  OchushaBBSThread *thread, const gchar *link,
 				  OchushaApplication *application);
 static gboolean link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
-				    BBSThread *thread, const gchar *link,
+				    OchushaBBSThread *thread,
+				    const gchar *link,
 				    OchushaApplication *application);
 static gboolean link_mouse_release_cb(BBSThreadView *view,
-				      GdkEventButton *event, BBSThread *thread,
+				      GdkEventButton *event,
+				      OchushaBBSThread *thread,
 				      const gchar *link,
 				      OchushaApplication *application);
 
-static void show_popup(OchushaApplication *application, BBSThread *thread,
+static void show_popup(OchushaApplication *application,
+		       OchushaBBSThread *thread,
 		       const gchar *link, gint x_pos, gint y_pos);
 static gboolean popup_delay_timeout(gpointer data);
 static void show_popup_real(void);
 static void hide_popup(void);
 
 static void render_bbs_thread(WorkerThread *employee, gpointer args);
-static gboolean start_thread_rendering(BBSThread *thread, const gchar *title,
+static gboolean start_thread_rendering(OchushaBBSThread *thread,
+				       const gchar *title,
 				       gpointer user_data);
-static gboolean render_response(BBSThread *thread, gint number,
-				const BBSResponse *response,
+static gboolean render_response(OchushaBBSThread *thread, gint number,
+				const OchushaBBSResponse *response,
 				gpointer user_data);
-static gboolean end_thread_rendering(BBSThread *thread, gboolean finished,
+static gboolean end_thread_rendering(OchushaBBSThread *thread,
+				     gboolean finished,
 				     gpointer user_data);
 static void start_element_cb(void *context, const char *name,
 			     const char *const attrs[]);
@@ -116,7 +123,7 @@ typedef struct _RendererContext
 {
   ElementHandler handler;
   BBSThreadView *view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   OchushaApplication *application;
   gint last_read_number;
 
@@ -320,7 +327,7 @@ initialize_thread_ui(OchushaApplication *application)
 
 
 BBSThreadGUIInfo *
-ensure_bbs_thread_info(BBSThread *thread)
+ensure_bbs_thread_info(OchushaBBSThread *thread)
 {
   BBSThreadGUIInfo *info;
   BBS_THREAD_UI_LOCK
@@ -340,10 +347,10 @@ ensure_bbs_thread_info(BBSThread *thread)
 typedef struct _BBSThreadJobArgs
 {
   OchushaApplication *application;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   BBSThreadView *view;
   IconLabel *tab_label;
-  AsyncBuffer *buffer;
+  OchushaAsyncBuffer *buffer;
   gint start;
   gint number_of_responses;
   gboolean refresh;
@@ -351,7 +358,7 @@ typedef struct _BBSThreadJobArgs
 
 
 GtkWidget *
-open_bbs_thread(OchushaApplication *application, BBSThread *thread,
+open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
 		IconLabel *tab_label)
 {
   GtkWidget *thread_view;
@@ -367,8 +374,7 @@ open_bbs_thread(OchushaApplication *application, BBSThread *thread,
     {
       WorkerJob *job;
       BBSThreadJobArgs *job_args;
-      AsyncBuffer *buffer;
-      const char *url;
+      OchushaAsyncBuffer *buffer;
 
       thread_view = bbs_thread_view_new(thread);
       gtk_widget_show(thread_view);
@@ -390,21 +396,12 @@ open_bbs_thread(OchushaApplication *application, BBSThread *thread,
 	  return NULL;
 	}
 
-      url = ochusha_bbs_thread_get_dat_url(thread);
-      if (url == NULL)
-	{
-	  free(job);
-	  free(job_args);
-	  gtk_object_sink(GTK_OBJECT(thread_view));
-
-	  BBS_THREAD_UI_UNLOCK;
-	  return NULL;
-	}
-      
-      buffer = ochusha_read_from_url(&application->conf, url,
-				     info->last_modified,
-				     OCHUSHA_CACHE_TRY_UPDATE,
-				     &icon_indicator_funcs, tab_label);
+      buffer = ochusha_bbs_thread_get_responses_source(thread,
+						&application->conf,
+						info->last_modified,
+						OCHUSHA_CACHE_TRY_UPDATE,
+						&icon_indicator_funcs,
+						tab_label);
 
       if (buffer == NULL)
 	{
@@ -505,7 +502,7 @@ link_popup_menu_destructed_cb(gpointer data)
 
 static gboolean
 link_mouse_over_cb(BBSThreadView *view, GdkEventMotion *event,
-		   BBSThread *thread, const gchar *link,
+		   OchushaBBSThread *thread, const gchar *link,
 		   OchushaApplication *application)
 {
   GtkStatusbar *statusbar = application->statusbar;
@@ -531,7 +528,7 @@ link_mouse_over_cb(BBSThreadView *view, GdkEventMotion *event,
 
 static gboolean
 link_mouse_out_cb(BBSThreadView *view, GdkEventMotion *event,
-		  BBSThread *thread, const gchar *link,
+		  OchushaBBSThread *thread, const gchar *link,
 		  OchushaApplication *application)
 {
   GtkStatusbar *statusbar = application->statusbar;
@@ -554,7 +551,7 @@ link_mouse_out_cb(BBSThreadView *view, GdkEventMotion *event,
 
 static gboolean
 link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
-		    BBSThread *thread, const gchar *link,
+		    OchushaBBSThread *thread, const gchar *link,
 		    OchushaApplication *application)
 {
 #if DEBUG_GUI_MOST
@@ -581,7 +578,7 @@ link_mouse_press_cb(BBSThreadView *view, GdkEventButton *event,
 
 static gboolean
 link_mouse_release_cb(BBSThreadView *view, GdkEventButton *event,
-		      BBSThread *thread, const gchar *link,
+		      OchushaBBSThread *thread, const gchar *link,
 		      OchushaApplication *application)
 {
 #if DEBUG_GUI_MOST
@@ -601,9 +598,9 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 {
   BBSThreadJobArgs *job_args = (BBSThreadJobArgs *)args;
   OchushaApplication *application = job_args->application;
-  BBSThread *thread = job_args->thread;
+  OchushaBBSThread *thread = job_args->thread;
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
-  AsyncBuffer *buffer = job_args->buffer;
+  OchushaAsyncBuffer *buffer = job_args->buffer;
   gchar default_text_buffer[DEFAULT_BUFFER_SIZE];
   RendererContext context =
     {
@@ -675,12 +672,13 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 #endif
     }
 
-  ochusha_analyze_dat(thread, buffer,
-		      job_args->start, job_args->number_of_responses,
-		      start_thread_rendering,
-		      render_response,
-		      end_thread_rendering,
-		      &context);
+  ochusha_bbs_thread_parse_responses(thread, buffer,
+				     job_args->start,
+				     job_args->number_of_responses,
+				     start_thread_rendering,
+				     render_response,
+				     end_thread_rendering,
+				     &context);
 
   update_threadlist_entry(job_args->application, thread);
 
@@ -688,21 +686,6 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
   fprintf(stderr, "render_bbs_thread<done>: view=0x%x, view->ref_count=%d\n", (int)job_args->view, G_OBJECT(job_args->view)->ref_count);
 #endif
 
-#if 0
-  /* ٥Ȥ̵ʤΤԤäƤߤ¸ */
-  while (gtk_events_pending())
-    gtk_main_iteration();
-#endif
-
-#if 0
-  /*
-   * MEMO: ǥ뤵ΤϤäѤ桼ӥƥʡ
-   *       ä˥ͥåȥ٤硣
-   */
-  gdk_threads_enter();
-  bbs_thread_view_scroll_to_mark(job_args->view, info->last_read);
-  gdk_threads_leave();
-#endif
   if (job_args->tab_label != NULL)
     g_object_unref(G_OBJECT(job_args->tab_label));
 #if DEBUG_WIDGET
@@ -749,7 +732,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 
 
 static gboolean
-start_thread_rendering(BBSThread *thread, const gchar *title,
+start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 		       gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
@@ -794,7 +777,8 @@ start_thread_rendering(BBSThread *thread, const gchar *title,
 #define LARGE_COLON		"\357\274\232"
 
 static gboolean
-render_response(BBSThread *thread, gint number, const BBSResponse *response,
+render_response(OchushaBBSThread *thread, gint number,
+		const OchushaBBSResponse *response,
 		gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
@@ -896,7 +880,8 @@ render_response(BBSThread *thread, gint number, const BBSResponse *response,
 
 
 static gboolean
-end_thread_rendering(BBSThread *thread, gboolean finished, gpointer user_data)
+end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
+		     gpointer user_data)
 {
   RendererContext *context = (RendererContext *)user_data;
   BBSThreadView *view = context->view;
@@ -1100,44 +1085,42 @@ characters_cb(void *user_data, const char *ch, int len)
 
 
 static gboolean
-prepare_buffer_for_popup(OchushaApplication *application, BBSThread *thread,
+prepare_buffer_for_popup(OchushaApplication *application,
+			 OchushaBBSThread *thread,
 			 const gchar *link,
-			 int *response_number, AsyncBuffer **buffer)
+			 unsigned int *response_from,
+			 unsigned int *response_to,
+			 OchushaAsyncBuffer **buffer)
 {
-  int len;
-  unsigned int number;
+  unsigned int from = 0;
+  unsigned int to = 0;
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
-  const char *url;
-  char *tmp_pos;
 
-  if (strncmp(link, "../", 3) == 0)
-    link += 3;	/* ɤФ */
-
-  /*
-   * 쥹ʬ¸ߤǧ
-   */
-  tmp_pos = strrchr(link, '/');
-  if (tmp_pos == NULL)
+  if (application->maximum_number_of_popup_responses < 1)
     return FALSE;
 
-  len = tmp_pos - link;
+  if (!ochusha_bbs_thread_check_url(thread, link, &from, &to))
+    return FALSE;
 
-  if (strncmp(thread->pseudo_path, link, len) != 0)
-    {
-#if DEBUG_GUI
-      fprintf(stderr, "pseudo_path=\"%s\", link=\"%s\"\n",
-	      thread->pseudo_path, link);
+#if DEBUG_GUI_MOST
+  fprintf(stderr, "prepare_buffer_for_popup(): from=%d, to=%d\n", from, to);
 #endif
-      return FALSE;	/* ƱؤΥ󥯤ʤ */
+
+  if ((from == 0 && to == 0) || from > thread->number_of_responses_read)
+    return FALSE;
+
+  if (to > thread->number_of_responses_read)
+    to = thread->number_of_responses_read;
+
+  if (to > 0 && from > to)
+    {
+      unsigned int tmp = to;
+      to = from;
+      from = tmp;
     }
 
-  if (sscanf(tmp_pos + 1, "%u", &number) != 1)
-    return FALSE;
-
-  if (number < 1 || number > thread->number_of_responses_read)
-    return FALSE;
-
-  *response_number = number;
+  *response_from = from;
+  *response_to = to;
 
   /*
    * ΤȤɽƤ륹ɬdat_buffer˥ХåեäƤ뤬
@@ -1150,12 +1133,10 @@ prepare_buffer_for_popup(OchushaApplication *application, BBSThread *thread,
       return TRUE;
     }
 
-  url = ochusha_bbs_thread_get_dat_url(thread);
-  if (url == NULL)
-    return FALSE;
-
-  *buffer = ochusha_read_from_url(&application->conf, url, info->last_modified,
-				  OCHUSHA_CACHE_ONLY, NULL, NULL);
+  *buffer = ochusha_bbs_thread_get_responses_source(thread, &application->conf,
+						    info->last_modified,
+						    OCHUSHA_CACHE_ONLY,
+						    NULL, NULL);
   info->dat_buffer = *buffer;
 
   return (*buffer != NULL);
@@ -1252,8 +1233,8 @@ popup_realize_cb(GtkWidget *widget, gpointer data)
 
 
 static void
-render_popup_response(BBSThread *thread, AsyncBuffer *buffer,
-		      gint response_number)
+render_popup_response(OchushaBBSThread *thread, OchushaAsyncBuffer *buffer,
+		      gint response_from, gint num_responses)
 {
   GtkWidget *view = bbs_thread_view_new(thread);
   bbs_thread_view_set_wrap_mode(BBS_THREAD_VIEW(view), GTK_WRAP_NONE);
@@ -1279,39 +1260,60 @@ render_popup_response(BBSThread *thread, AsyncBuffer *buffer,
   bbs_thread_view_hide_scrollbar(popup_renderer_context.view);
   popup_renderer_context.link_text_length = 0;
   popup_renderer_context.thread = thread;
-  gdk_threads_leave();	/* ˤ̣ */
-  ochusha_analyze_dat(thread, buffer, response_number - 1, 1,
-		      NULL, render_response, NULL, &popup_renderer_context);
-  gdk_threads_enter();	/* ˤ̣ */
+
+#if DEBUG_GUI_MOST
+  if (num_responses > 1)
+    fprintf(stderr, "from=%d, num=%d\n", response_from, num_responses);
+#endif
+
+  gdk_threads_leave();
+  ochusha_bbs_thread_parse_responses(thread, buffer,
+				     response_from - 1, num_responses,
+				     NULL, render_response, NULL,
+				     &popup_renderer_context);
+  gdk_threads_enter();
 }
 
 
 static void
-show_popup(OchushaApplication *application, BBSThread *thread,
+show_popup(OchushaApplication *application, OchushaBBSThread *thread,
 	   const gchar *link, gint x_pos, gint y_pos)
 {
-  gint response_number = 0;
-  AsyncBuffer *buffer;
+  OchushaAsyncBuffer *buffer;
+  gint response_from = 0;
+  gint response_to = 0;
+  gint num_responses;
 
 #if DEBUG_GUI_MOST
   fprintf(stderr, "show_popup: link=\"%s\", x_pos=%d, y_pos=%d\n",
 	  link, x_pos, y_pos);
 #endif
   if (!prepare_buffer_for_popup(application, thread, link,
-				&response_number, &buffer))
+				&response_from, &response_to, &buffer))
     {
 #if DEBUG_POPUP
-      if (response_number != 0)
-	fprintf(stderr, "Popup cannot be prepared...why?\n");
+      fprintf(stderr, "show_popup(): from=%d to=%d\n",
+	      response_from, response_to);
+      fprintf(stderr, "Popup cannot be prepared...why?\n");
 #endif
       return;
     }
 
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "response #%d\n", response_number);
-#endif
+  if (response_from == 0)
+    response_from
+      = response_to - application->maximum_number_of_popup_responses;
+  if (response_to == 0)
+    response_to = response_from;
 
-  render_popup_response(thread, buffer, response_number);
+  num_responses = response_to - response_from + 1;
+  if (num_responses > application->maximum_number_of_popup_responses)
+    num_responses = application->maximum_number_of_popup_responses;
+
+#if DEBUG_POPUP
+      fprintf(stderr, "show_popup(): from=%d num_responses=%d\n",
+	      response_from, num_responses);
+#endif
+  render_popup_response(thread, buffer, response_from, num_responses);
 
   popup_x_pos = x_pos;
   popup_y_pos = y_pos;
@@ -1484,7 +1486,7 @@ hide_popup(void)
 
 void
 refresh_thread(OchushaApplication *application, GtkWidget *widget,
-	       BBSThread *thread, IconLabel *tab_label)
+	       OchushaBBSThread *thread, IconLabel *tab_label)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
   BBSThreadView *view = BBS_THREAD_VIEW(widget);
@@ -1496,9 +1498,8 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 
   BBS_THREAD_UI_LOCK
     {
-      AsyncBuffer *buffer;
-      AsyncBuffer *old_buffer;
-      const char *url;
+      OchushaAsyncBuffer *buffer;
+      OchushaAsyncBuffer *old_buffer;
 
       if (!info->rendering_done)
 	{
@@ -1516,15 +1517,14 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 	  goto error_exit;
 	}
 
-      url = ochusha_bbs_thread_get_dat_url(thread);
-      if (url == NULL)
-	goto error_exit;
-
       old_buffer = info->dat_buffer;
-      buffer = ochusha_read_from_url(&application->conf, url,
-				     info->last_modified,
-				     OCHUSHA_CACHE_TRY_UPDATE,
-				     &icon_indicator_funcs, tab_label);
+      buffer = ochusha_bbs_thread_get_responses_source(thread,
+						&application->conf,
+						info->last_modified,
+						OCHUSHA_CACHE_TRY_UPDATE,
+						&icon_indicator_funcs,
+						tab_label);
+
       if (buffer == NULL)
 	{
 	  fprintf(stderr, "Couldn't access network!\n");
@@ -1581,7 +1581,7 @@ refresh_thread(OchushaApplication *application, GtkWidget *widget,
 
 
 void
-go_to_the_first_response(GtkWidget *widget, BBSThread *thread)
+go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
   BBSThreadView *view;
   g_return_if_fail(widget != NULL);
@@ -1591,7 +1591,7 @@ go_to_the_first_response(GtkWidget *widget, BBSThread *thread)
 
 
 void
-go_to_the_last_response(GtkWidget *widget, BBSThread *thread)
+go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
   BBSThreadView *view;
   g_return_if_fail(widget != NULL);
@@ -1601,11 +1601,12 @@ go_to_the_last_response(GtkWidget *widget, BBSThread *thread)
 
 
 void
-jump_to_new_comer_response(GtkWidget *widget, BBSThread *thread)
+jump_to_new_comer_response(GtkWidget *widget, OchushaBBSThread *thread)
 {
   BBSThreadView *view;
   g_return_if_fail(widget != NULL && thread != NULL
 		   && thread->user_data != NULL);
   view = BBS_THREAD_VIEW(widget);
-  bbs_thread_view_scroll_to_mark(view, ((BBSThreadGUIInfo *)thread->user_data)->last_read);
+  bbs_thread_view_scroll_to_mark(view,
+			((BBSThreadGUIInfo *)thread->user_data)->last_read);
 }
