@@ -23,13 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: bbs_thread_ui.h,v 1.1.1.1 2003/05/10 16:34:24 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
 #define _BBSTHREAD_UI_H_
 
-#include "asyncbuf.h"
+#include "ochusha_bbs_thread.h"
+#include "ochusha_async_buffer.h"
 #include "threadlist_view.h"
 #include "icon_label.h"
 
@@ -57,7 +58,7 @@ typedef struct _BBSThreadGUIInfo
   gboolean rendering_done;
 
   /* ɽDATեΥХåե */
-  AsyncBuffer *dat_buffer;
+  OchushaAsyncBuffer *dat_buffer;
 
   char *last_modified;
 
@@ -76,15 +77,15 @@ typedef enum
 
 
 void initialize_thread_ui(OchushaApplication *application);
-BBSThreadGUIInfo * ensure_bbs_thread_info(BBSThread *thread);
-GtkWidget *open_bbs_thread(OchushaApplication *application, BBSThread *thread,
-			   IconLabel *tab_label);
+BBSThreadGUIInfo * ensure_bbs_thread_info(OchushaBBSThread *thread);
+GtkWidget *open_bbs_thread(OchushaApplication *application,
+			   OchushaBBSThread *thread, IconLabel *tab_label);
 
 void refresh_thread(OchushaApplication *application, GtkWidget *widget,
-		    BBSThread *thread, IconLabel *tab_label);
-void go_to_the_first_response(GtkWidget *widget, BBSThread *thread);
-void go_to_the_last_response(GtkWidget *widget, BBSThread *thread);
-void jump_to_new_comer_response(GtkWidget *widget, BBSThread *thread);
+		    OchushaBBSThread *thread, IconLabel *tab_label);
+void go_to_the_first_response(GtkWidget *widget, OchushaBBSThread *thread);
+void go_to_the_last_response(GtkWidget *widget, OchushaBBSThread *thread);
+void jump_to_new_comer_response(GtkWidget *widget, OchushaBBSThread *thread);
 
 
 #ifdef __cplusplus
