@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: bbs_thread_view.c,v 1.1.1.1 2003/05/10 16:34:25 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,8 @@
 #include "ochusha.h"
 #include "ochusha_ui.h"
 
+#include "ochusha_bbs_thread.h"
+
 #include "marshal.h"
 
 #include "worker.h"
@@ -704,7 +706,7 @@ button_release_event_cb(GtkTextView *text_view, GdkEventButton *event,
 
 
 GtkWidget *
-bbs_thread_view_new(BBSThread *thread)
+bbs_thread_view_new(OchushaBBSThread *thread)
 {
   BBSThreadView *view = BBS_THREAD_VIEW(g_object_new(BBS_THREAD_VIEW_TYPE,
 						     NULL));
@@ -714,7 +716,7 @@ bbs_thread_view_new(BBSThread *thread)
 
 
 void
-bbs_thread_view_set_thread(BBSThreadView *view, BBSThread *thread)
+bbs_thread_view_set_thread(BBSThreadView *view, OchushaBBSThread *thread)
 {
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
@@ -722,7 +724,7 @@ bbs_thread_view_set_thread(BBSThreadView *view, BBSThread *thread)
 }
 
 
-BBSThread *
+OchushaBBSThread *
 bbs_thread_view_get_thread(BBSThreadView *view)
 {
   g_return_val_if_fail(IS_BBS_THREAD_VIEW(view), NULL);
