@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: bbs_thread_view.h,v 1.1.1.1 2003/05/10 16:34:25 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -63,7 +63,7 @@ struct _BBSThreadView
 
   /* ʥطǻȤ */
   gint last_offset;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   GHashTable *link_table;	/* offset=>linkʥơ֥ */
 
   GdkCursor *ibeam_cursor;
@@ -79,16 +79,16 @@ struct _BBSThreadViewClass
 
   void (*link_mouse_over)(BBSThreadView *bbs_thread_view,
 			  GdkEventMotion *event,
-			  BBSThread *thread, const gchar *link);
+			  OchushaBBSThread *thread, const gchar *link);
   void (*link_mouse_out)(BBSThreadView *bbs_thread_view,
 			 GdkEventMotion *event,
-			 BBSThread *thread, const gchar *link);
+			 OchushaBBSThread *thread, const gchar *link);
   void (*link_mouse_press)(BBSThreadView *bbs_therad_view,
 			   GdkEventButton *event,
-			   BBSThread *thread, const gchar *link);
+			   OchushaBBSThread *thread, const gchar *link);
   void (*link_mouse_release)(BBSThreadView *bbs_thread_view,
 			     GdkEventButton *event,
-			     BBSThread *thread, const gchar *link);
+			     OchushaBBSThread *thread, const gchar *link);
 
   void (*scroll_to)(BBSThreadView *bbs_thread_view, gint to_where);
 };
@@ -103,9 +103,9 @@ GType bbs_thread_view_get_type(void);
 
 GtkTextTagTable *bbs_thread_view_class_get_default_tag_table(BBSThreadViewClass *klass);
 
-GtkWidget *bbs_thread_view_new(BBSThread *thread);
-void bbs_thread_view_set_thread(BBSThreadView *view, BBSThread *thread);
-BBSThread *bbs_thread_view_get_thread(BBSThreadView *view);
+GtkWidget *bbs_thread_view_new(OchushaBBSThread *thread);
+void bbs_thread_view_set_thread(BBSThreadView *view, OchushaBBSThread *thread);
+OchushaBBSThread *bbs_thread_view_get_thread(BBSThreadView *view);
 
 void bbs_thread_view_set_wrap_mode(BBSThreadView *view, GtkWrapMode mode);
 GtkWrapMode bbs_thread_view_get_wrap_mode(BBSThreadView *view);
