@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: board_properties.c,v 1.1.1.1 2003/05/10 16:34:25 fuyu Exp $
  */
 
 #include "ochusha_ui.h"
@@ -42,7 +42,7 @@
 typedef struct _DialogStates
 {
   OchushaApplication *application;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
   BulletinBoardGUIInfo *info;
 
   ThreadlistFilterSetting *setting;
@@ -57,10 +57,10 @@ typedef struct _DialogStates
 
 
 static GtkWidget *build_board_info_frame(OchushaApplication *application,
-					 BulletinBoard *board,
+					 OchushaBulletinBoard *board,
 					 DialogStates *states);
 static GtkWidget *build_filter_setting_frame(OchushaApplication *application,
-					     BulletinBoard *board,
+					     OchushaBulletinBoard *board,
 					     DialogStates *states);
 
 static void setting_changed_cb(ThreadlistFilterSetting *setting,
@@ -102,7 +102,8 @@ initialize_board_properties(OchushaApplication *application)
 
 
 void
-open_board_properties(OchushaApplication *application, BulletinBoard *board)
+open_board_properties(OchushaApplication *application,
+		      OchushaBulletinBoard *board)
 {
   GtkWidget *dialog;
   GtkWidget *frame;
@@ -323,8 +324,8 @@ board_properties_response_cb(GtkWidget *dialog, gint response_id,
 
 
 static GtkWidget *
-build_board_info_frame(OchushaApplication *application, BulletinBoard *board,
-		       DialogStates *states)
+build_board_info_frame(OchushaApplication *application,
+		       OchushaBulletinBoard *board, DialogStates *states)
 {
   GtkWidget *table;
   GtkWidget *tmp_widget;
@@ -365,7 +366,7 @@ build_board_info_frame(OchushaApplication *application, BulletinBoard *board,
 
 static GtkWidget *
 build_filter_setting_frame(OchushaApplication *application,
-			   BulletinBoard *board, DialogStates *states)
+			   OchushaBulletinBoard *board, DialogStates *states)
 {
   GtkWidget *filter_frame = gtk_frame_new(_("Filter Setting"));
 
