@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: boardlist_ui.c,v 1.2 2003/05/11 20:55:12 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,8 @@
 #include "ochusha.h"
 #include "ochusha_ui.h"
 
+#include "ochusha_utils_2ch.h"
+
 #include "bbs_thread_ui.h"
 #include "board_properties.h"
 #include "boardlist_ui.h"
@@ -51,41 +53,46 @@
 
 
 #if DEBUG_WIDGET_MOST
-static void select_category_cb(BoardlistView *view, BoardCategory *category,
+static void select_category_cb(BoardlistView *view,
+			       OchushaBoardCategory *category,
 			       gpointer user_data);
 #endif
-static void read_category_attributes(BoardCategory *category,
-				     GHashTable *cat_attrs,
-				     gpointer user_data);
-static void read_board_attributes(BulletinBoard *board,
-				  GHashTable *board_attrs, gpointer user_data);
+static void boardlist_read_category_element_cb(OchushaBBSTable *table,
+					       OchushaBoardCategory *category,
+					       GHashTable *cat_attributes,
+					       OchushaApplication *appl);
+static void boardlist_read_board_element_cb(OchushaBBSTable *table,
+					    OchushaBulletinBoard *board,
+					    GHashTable *cat_attributes,
+					    OchushaApplication *appl);
 
-static void write_category_attributes(FILE *boardlist_xml,
-				      BoardCategory *category,
-				      gpointer user_data);
-static void write_board_attributes(FILE *boardlist_xml, BulletinBoard *board,
-				   gpointer user_data);
+static void boardlist_write_category_element_cb(OchushaBBSTable *table,
+						OchushaBoardCategory *category,
+						FILE *boardlist_xml,
+						OchushaApplication *appl);
+static void boardlist_write_board_element_cb(OchushaBBSTable *table,
+					     OchushaBulletinBoard *board,
+					     FILE *boardlist_xml,
+					     OchushaApplication *appl);
 
 static void write_threadlist(gpointer data, gpointer user_data);
-static void write_thread_attributes(FILE *threadlist_xml, BBSThread *thread,
-				    gpointer user_data);
 
 static void build_boardlist(WorkerThread *employee, gpointer args);
 
-static void setup_boardlist(OchushaApplication *application,
-			    BBSTable *bbs_table);
+static void setup_boardlist(OchushaApplication *application);
+
 static void filter_toggled_cb(GtkToggleButton *toggle_button,
 			      OchushaApplication *application);
 static void item_view_required_cb(PanedNotebook *paned_notebook,
-				  BulletinBoard *board, GtkWidget **item_view,
+				  OchushaBulletinBoard *board, GtkWidget **item_view,
 				  const gchar **title, GtkWidget **tab_label,
 				  OchushaApplication *application);
 static void item_view_being_closed_cb(PanedNotebook *paned_notebook,
-				      BulletinBoard *board,
+				      OchushaBulletinBoard *board,
 				      GtkWidget *item_view,
 				      OchushaApplication *application);
 static void item_view_closed_cb(PanedNotebook *paned_notebook,
-				BulletinBoard *board, GtkWidget *item_view,
+				OchushaBulletinBoard *board, GtkWidget *item_view,
 				OchushaApplication *application);
 static void page_switched_cb(PanedNotebook *paned_notebook,
 			     GtkWidget *previous_page, GtkWidget *new_page,
@@ -99,10 +106,12 @@ static void open_board_properties_button_cb(GtkWidget *widget,
 					    OchushaApplication *application);
 static void refresh_board_button_cb(GtkWidget *widget,
 				    OchushaApplication *application);
+static void start_threadlist_search_button_cb(GtkWidget *widget,
+					      OchushaApplication *application);
 
 
 
-/* Υå˰٤ǤⳫ(BulletinBoard *)Υꥹȡ*/
+/* Υå˰٤ǤⳫ(OchushaBulletinBoard *)Υꥹȡ*/
 static GSList *board_list;
 
 static pthread_mutex_t board_list_lock;
@@ -126,7 +135,6 @@ static pthread_mutex_t board_list_lock;
 void
 initialize_boardlist(OchushaApplication *application)
 {
-  BBSTable *bbs_table;
   GtkToolbar *toolbar;
   GtkWidget *filter_button;
 
@@ -189,6 +197,13 @@ initialize_boardlist(OchushaApplication *application)
 			   application,
 			   0);
 
+  gtk_toolbar_insert_stock(toolbar, GTK_STOCK_FIND,
+			   _("Start text search on current threadlist"),
+			   "start_text_search_on_threadlist",
+			   GTK_SIGNAL_FUNC(start_threadlist_search_button_cb),
+			   application,
+			   0);
+
 #if DEBUG_WIDGET_MOST
   g_signal_connect(G_OBJECT(application->boardlist_view), "select_category",
 		   G_CALLBACK(select_category_cb), application);
@@ -206,14 +221,30 @@ initialize_boardlist(OchushaApplication *application)
 		   "page_switched", G_CALLBACK(page_switched_cb),
 		   application);
 
-  bbs_table = ochusha_read_boardlist_xml(&application->conf,
-					 read_category_attributes,
-					 read_board_attributes,
-					 NULL);
+  application->table = ochusha_bbs_table_new();
 
-  if (bbs_table != NULL)
+  /* γĥǥ¸ */
+  g_signal_connect(G_OBJECT(application->table),
+		   "boardlist_read_category_element",
+		   G_CALLBACK(boardlist_read_category_element_cb),
+		   application);
+  g_signal_connect(G_OBJECT(application->table),
+		   "boardlist_read_board_element",
+		   G_CALLBACK(boardlist_read_board_element_cb),
+		   application);
+  g_signal_connect(G_OBJECT(application->table),
+		   "boardlist_write_category_element",
+		   G_CALLBACK(boardlist_write_category_element_cb),
+		   application);
+  g_signal_connect(G_OBJECT(application->table),
+		   "boardlist_write_board_element",
+		   G_CALLBACK(boardlist_write_board_element_cb),
+		   application);
+
+  if (ochusha_bbs_table_read_boardlist_xml(application->table,
+					   &application->conf))
     {
-      setup_boardlist(application, bbs_table);
+      setup_boardlist(application);
       return;
     }
 
@@ -254,16 +285,14 @@ finalize_boardlist(OchushaApplication *application)
 	  = gtk_paned_get_position(GTK_PANED(current_board));
     }
 
-  if (application->bbs_table != NULL)
+  if (application->table != NULL)
     {
-      if (!ochusha_write_boardlist_xml(&application->conf,
-				       application->bbs_table,
-				       write_category_attributes,
-				       write_board_attributes, NULL))
-	fprintf(stderr, "Couldn't write boardlist.xml.\n");
+      if (!ochusha_bbs_table_write_boardlist_xml(application->table,
+						 &application->conf))
+	fprintf(stderr, "Couldn't write boardlist2.xml.\n");
     }
 
-  g_slist_foreach((GSList *)board_list, write_threadlist, application);
+  g_slist_foreach(board_list, write_threadlist, application);
 }
 
 
@@ -272,14 +301,14 @@ void
 make_new_thread(OchushaApplication *application)
 {
   PanedNotebook *contents_window;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
 
   g_return_if_fail(application != NULL
 		   && application->contents_window != NULL);
 
   contents_window = PANED_NOTEBOOK(application->contents_window);
 
-  board = (BulletinBoard *)paned_notebook_get_current_item(contents_window);
+  board = (OchushaBulletinBoard *)paned_notebook_get_current_item(contents_window);
   if (board == NULL)
     return;
 
@@ -294,14 +323,14 @@ void
 open_current_board_properties(OchushaApplication *application)
 {
   PanedNotebook *contents_window;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
 
   g_return_if_fail(application != NULL
 		   && application->contents_window != NULL);
 
   contents_window = PANED_NOTEBOOK(application->contents_window);
 
-  board = (BulletinBoard *)paned_notebook_get_current_item(contents_window);
+  board = (OchushaBulletinBoard *)paned_notebook_get_current_item(contents_window);
   if (board == NULL)
     return;
 
@@ -313,14 +342,14 @@ void
 refresh_current_threadlist(OchushaApplication *application)
 {
   PanedNotebook *contents_window;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
 
   g_return_if_fail(application != NULL
 		   && application->contents_window != NULL);
 
   contents_window = PANED_NOTEBOOK(application->contents_window);
 
-  board = (BulletinBoard *)paned_notebook_get_current_item(contents_window);
+  board = (OchushaBulletinBoard *)paned_notebook_get_current_item(contents_window);
   if (board == NULL)
     return;
 
@@ -331,7 +360,7 @@ refresh_current_threadlist(OchushaApplication *application)
 static void
 refresh_threadlist_helper(gpointer data, gpointer user_data)
 {
-  BulletinBoard *board = (BulletinBoard *)data;
+  OchushaBulletinBoard *board = (OchushaBulletinBoard *)data;
   OchushaApplication *application = (OchushaApplication *)user_data;
   refresh_threadlist_view(application, board);
 }
@@ -352,7 +381,7 @@ refresh_current_threadlist_all(OchushaApplication *application)
 static void
 redraw_threadlist_helper(gpointer data, gpointer user_data)
 {
-  BulletinBoard *board = (BulletinBoard *)data;
+  OchushaBulletinBoard *board = (OchushaBulletinBoard *)data;
   OchushaApplication *application = (OchushaApplication *)user_data;
   redraw_threadlist_view(application, board);
 }
@@ -371,19 +400,42 @@ redraw_current_threadlist_all(OchushaApplication *application)
 }
 
 
+void
+start_current_threadlist_search(OchushaApplication *application)
+{
+  GtkWidget *widget;
+
+  g_return_if_fail(application != NULL
+		   && application->contents_window != NULL);
+
+  widget = paned_notebook_get_current_item_view(
+				PANED_NOTEBOOK(application->contents_window));
+  if (widget == NULL)
+    return;
+  g_return_if_fail(IS_PANED_NOTEBOOK(widget));
+
+  widget = paned_notebook_get_selector(PANED_NOTEBOOK(widget));
+  if (widget == NULL)
+    return;
+  g_return_if_fail(IS_THREADLIST_VIEW(widget));
+
+  threadlist_view_start_interactive_search(THREADLIST_VIEW(widget));
+}
+
+
 /*
- * ϤʤΤѰդषBulletinBoardѲưŪ˻
- * ƼΧŪб٤ʤΤʡ
+ * ϤʤΤѰդषOchushaBulletinBoardѲưŪ
+ * ˻ΤƼΧŪб٤ʤΤʡ
  */
 void
 fix_filter_button_state(OchushaApplication *application)
 {
   PanedNotebook *contents_window;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
   g_return_if_fail(application != NULL
 		   && application->contents_window != NULL);
   contents_window = PANED_NOTEBOOK(application->contents_window);
-  board = (BulletinBoard *)paned_notebook_get_current_item(contents_window);
+  board = (OchushaBulletinBoard *)paned_notebook_get_current_item(contents_window);
   if (board == NULL)
     return;
 
@@ -393,7 +445,7 @@ fix_filter_button_state(OchushaApplication *application)
 
 
 void
-update_threadlist_entry(OchushaApplication *application, BBSThread *thread)
+update_threadlist_entry(OchushaApplication *application, OchushaBBSThread *thread)
 {
   PanedNotebook *board_view;
   ThreadlistView *threadlist_view;
@@ -429,8 +481,8 @@ filter_toggled_cb(GtkToggleButton *toggle_button,
 		  OchushaApplication *application)
 {
   PanedNotebook *board_pane = PANED_NOTEBOOK(application->contents_window);
-  BulletinBoard *board
-    = (BulletinBoard *)paned_notebook_get_current_item(board_pane);
+  OchushaBulletinBoard *board
+    = (OchushaBulletinBoard *)paned_notebook_get_current_item(board_pane);
   BulletinBoardGUIInfo *info;
 
 #if DEBUG_GUI_MOST
@@ -459,7 +511,7 @@ filter_toggled_cb(GtkToggleButton *toggle_button,
 
 #if DEBUG_WIDGET_MOST
 static void
-select_category_cb(BoardlistView *view, BoardCategory *category,
+select_category_cb(BoardlistView *view, OchushaBoardCategory *category,
 		   gpointer user_data)
 {
   fprintf(stderr, "select_category_cb: 0x%x, 0x%x, 0x%x\n",
@@ -469,17 +521,21 @@ select_category_cb(BoardlistView *view, BoardCategory *category,
 
 
 static void
-item_view_required_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
+item_view_required_cb(PanedNotebook *paned_notebook, OchushaBulletinBoard *board,
 		      GtkWidget **item_view, const gchar **title,
 		      GtkWidget **tab_label,
 		      OchushaApplication *application)
 {
+  OchushaBulletinBoard *board2;
 #if DEBUG_GUI_MOST
   fprintf(stderr, "boardlist_ui.c: item_view_required_cb called.\n");
 #endif
   *tab_label = get_tab_label(board->name);
   *item_view = open_bulletin_board(application, board, ICON_LABEL(*tab_label));
 
+  board2 = ochusha_bbs_table_lookup_board_by_url(application->table,
+						 board->base_url);
+
   if (*item_view == NULL)
     {
       gtk_object_sink(GTK_OBJECT(*tab_label));
@@ -500,11 +556,11 @@ item_view_required_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
 
 
 static void
-item_view_being_closed_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
+item_view_being_closed_cb(PanedNotebook *paned_notebook, OchushaBulletinBoard *board,
 			  GtkWidget *item_view,
 			  OchushaApplication *application)
 {
-  AsyncBuffer *buffer = snatch_subject_txt_buffer_for_board(board);
+  OchushaAsyncBuffer *buffer = snatch_subject_txt_buffer_for_board(board);
 
 #ifndef SUSPEND_ALL_FOR_DESTRUCTION	/* ¸ */
   /*
@@ -529,9 +585,9 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
     {
       gdk_threads_leave();
 
-      async_buffer_suspend(buffer);
-      async_buffer_terminate(buffer);
-      async_buffer_resume(buffer);
+      ochusha_async_buffer_suspend(buffer);
+      ochusha_async_buffer_terminate(buffer);
+      ochusha_async_buffer_resume(buffer);
 
       gdk_threads_enter();
     }
@@ -547,17 +603,17 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
 
   gdk_threads_leave();
 
-  async_buffer_suspend_all();
+  ochusha_async_buffer_suspend_all();
 
   if (buffer != NULL)
-    async_buffer_terminate(buffer);
+    ochusha_async_buffer_terminate(buffer);
 
   gdk_threads_enter();
 
   while (gtk_events_pending())
     gtk_main_iteration();
 
-  async_buffer_resume_all();
+  ochusha_async_buffer_resume_all();
 #endif
 
   if (buffer != NULL)
@@ -567,7 +623,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
 
 
 static void
-item_view_closed_cb(PanedNotebook *paned_notebook, BulletinBoard *board,
+item_view_closed_cb(PanedNotebook *paned_notebook, OchushaBulletinBoard *board,
 		    GtkWidget *item_view, OchushaApplication *application)
 {
 #if DEBUG_GUI_MOST
@@ -609,8 +665,8 @@ page_switched_cb(PanedNotebook *paned_notebook,
 
   if (new_page != NULL)
     {
-      BulletinBoard *board
-	= (BulletinBoard *)paned_notebook_get_item(paned_notebook, new_page);
+      OchushaBulletinBoard *board
+	= (OchushaBulletinBoard *)paned_notebook_get_item(paned_notebook, new_page);
       BulletinBoardGUIInfo *info;
 
       g_return_if_fail(board != NULL);
@@ -627,33 +683,43 @@ page_switched_cb(PanedNotebook *paned_notebook,
 
 
 static void
-read_category_attributes(BoardCategory *category, GHashTable *cat_attrs,
-			 gpointer user_data)
+boardlist_read_category_element_cb(OchushaBBSTable *table,
+				   OchushaBoardCategory *category,
+				   GHashTable *category_attributes,
+				   OchushaApplication *application)
 {
   BoardCategoryInfo *info = category->user_data;
+#if DEBUG_GUI
+  fprintf(stderr, "boardlist_read_category_element_cb.\n");
+#endif
 
   if (info == NULL)
     {
-      info = calloc(1, sizeof(BoardCategoryInfo));
-      if (info == NULL)
-	return;
+      info = g_new0(BoardCategoryInfo, 1);
       category->user_data = info;
     }
 
-  info->expanded = get_attribute_boolean(cat_attrs, "expanded");
+  info->expanded = ochusha_utils_get_attribute_boolean(category_attributes, "expanded");
   return;
 }
 
 
 static void
-read_board_attributes(BulletinBoard *board, GHashTable *board_attrs,
-		      gpointer user_data)
+boardlist_read_board_element_cb(OchushaBBSTable *table,
+				OchushaBulletinBoard *board,
+				GHashTable *board_attributes,
+				OchushaApplication *application)
 {
   BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board);
-  info->last_modified = get_attribute_string(board_attrs, "last_modified");
-  info->enable_filter = get_attribute_boolean(board_attrs, "enable_filter");
-  info->filter.rule = get_attribute_string(board_attrs, "filter.rule");
-  info->filter.ignore_threshold = get_attribute_int(board_attrs, "filter.ignore_threshold");
+  info->last_modified = ochusha_utils_get_attribute_string(board_attributes,
+							   "last_modified");
+  info->enable_filter = ochusha_utils_get_attribute_boolean(board_attributes,
+							    "enable_filter");
+  info->filter.rule = ochusha_utils_get_attribute_string(board_attributes,
+							 "filter.rule");
+  info->filter.ignore_threshold
+    = ochusha_utils_get_attribute_int(board_attributes,
+				      "filter.ignore_threshold");
   return;
 }
 
@@ -667,10 +733,16 @@ read_board_attributes(BulletinBoard *board, GHashTable *board_attrs,
 
 
 static void
-write_category_attributes(FILE *boardlist_xml, BoardCategory *category,
-			  gpointer user_data)
+boardlist_write_category_element_cb(OchushaBBSTable *table,
+				    OchushaBoardCategory *category,
+				    FILE *boardlist_xml,
+				    OchushaApplication *application)
 {
   BoardCategoryInfo *info = (BoardCategoryInfo *)category->user_data;
+#if DEBUG_GUI
+  fprintf(stderr, "boardlist_write_category_element_cb.\n");
+#endif
+
   OUTPUT_CATEGORY_ATTRIBUTE_BOOLEAN(boardlist_xml, info, expanded);
 }
 
@@ -694,9 +766,12 @@ write_category_attributes(FILE *boardlist_xml, BoardCategory *category,
 	  "          <string>%s</string>\n"				\
 	  "        </attribute>\n", (board)->attribute)
 
+
 static void
-write_board_attributes(FILE *boardlist_xml, BulletinBoard *board,
-		       gpointer user_data)
+boardlist_write_board_element_cb(OchushaBBSTable *table,
+				 OchushaBulletinBoard *board,
+				 FILE *boardlist_xml,
+				 OchushaApplication *application)
 {
   BulletinBoardGUIInfo *info = (BulletinBoardGUIInfo *)board->user_data;
   OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, enable_filter);
@@ -717,44 +792,42 @@ write_board_attributes(FILE *boardlist_xml, BulletinBoard *board,
 static void
 write_threadlist(gpointer data, gpointer user_data)
 {
-  BulletinBoard *board = (BulletinBoard *)data;
+  OchushaBulletinBoard *board = (OchushaBulletinBoard *)data;
   OchushaApplication *application = (OchushaApplication *)user_data;
 
-  if (!ochusha_write_threadlist_xml(&application->conf, board,
-				    write_thread_attributes, NULL))
-    fprintf(stderr, "Couldn't write threadlist.xml.\n");
+  if (!ochusha_bulletin_board_write_threadlist_xml(board, &application->conf))
+    fprintf(stderr, "Couldn't write threadlist2.xml.\n");
 }
 
 
-#define OUTPUT_THREAD_ATTRIBUTE_INT(file, thread, attribute)		\
-  fprintf(file,								\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <int val=\"%d\"/>\n"					\
-	  "      </attribute>\n", (thread)->attribute)
-
-#define OUTPUT_THREAD_ATTRIBUTE_STRING(file, thread, attribute)		\
-  fprintf(file,								\
-	  "      <attribute name=\"" #attribute	"\">\n"			\
-	  "        <string>%s</string>\n"				\
-	  "      </attribute>\n", (thread)->attribute)
-
-static void
-write_thread_attributes(FILE *threadlist_xml, BBSThread *thread,
-			gpointer user_data)
+BoardCategoryInfo *
+ensure_board_category_info(OchushaBoardCategory *category)
 {
-  BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
-  ThreadlistInfo *threadlist_info;
-  if (info != NULL)
+  BoardCategoryInfo *info = category->user_data;
+
+  if (info == NULL)
     {
-      threadlist_info = &info->info;
-      OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, threadlist_info, view_flags);
-      OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, threadlist_info, view_rank);
-
-      if (info->last_modified != NULL)
-	OUTPUT_THREAD_ATTRIBUTE_STRING(threadlist_xml, info, last_modified);
-
-      OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, info, view_ignored);
+      info = g_new0(BoardCategoryInfo, 1);
+      category->user_data = info;
     }
+
+  return info;
+}
+
+
+static gboolean
+prepare_category(OchushaBoardCategory *category, gpointer user_data)
+{
+  ensure_board_category_info(category);
+  return TRUE;
+}
+
+
+static gboolean
+prepare_board(OchushaBulletinBoard *board, gpointer user_data)
+{
+  ensure_bulletin_board_info(board);
+  return TRUE;
 }
 
 
@@ -762,11 +835,10 @@ static void
 build_boardlist(WorkerThread *employee, gpointer args)
 {
   int status;
-  AsyncBuffer *buffer;
+  OchushaAsyncBuffer *buffer;
 
   OchushaApplication *application = (OchushaApplication *)args;
-  BBSTable *bbs_table = application->bbs_table;
-  iconv_t converter;
+  OchushaBBSTable *table = application->table;
 
 #if DEBUG_THREAD_MOST
   fprintf(stderr, "build_boardlist thread is invoked.\n");
@@ -782,18 +854,7 @@ build_boardlist(WorkerThread *employee, gpointer args)
       abort();
     }
 
-  if (bbs_table == NULL)
-    bbs_table = ochusha_bbs_table_new();
-
-  if (bbs_table == NULL)
-    {
-      buffer = NULL;
-      goto cleanup_before_return;
-    }
-
-  buffer = ochusha_read_from_url(&application->conf,
-				 application->conf.bbsmenu_url, NULL,
-				 OCHUSHA_CACHE_IGNORE, NULL, NULL);
+  buffer = ochusha_utils_2ch_get_bbsmenu(&application->conf, NULL, NULL);
 
   if (buffer == NULL)
     {
@@ -802,26 +863,19 @@ build_boardlist(WorkerThread *employee, gpointer args)
       return;
     }
 
-  converter = iconv_open("UTF-8//IGNORE", "CP932");
-  if (converter == (iconv_t)-1)
-    {
-      goto cleanup_before_return;
-    }
-
-  if (ochusha_bbs_table_analyze(bbs_table, buffer,
-				converter, NULL, NULL, NULL))
+  if (ochusha_utils_2ch_analyze_bbsmenu(table, buffer,
+					prepare_category,
+					prepare_board,
+					NULL,	/* TODO: İžб */
+					application))
     {
       gdk_threads_enter();
-      setup_boardlist(application, bbs_table);
+      setup_boardlist(application);
       gdk_threads_leave();
 
-      ochusha_write_boardlist_xml(&application->conf, bbs_table,
-				  write_category_attributes,
-				  write_board_attributes, NULL);
+      ochusha_bbs_table_write_boardlist_xml(table, &application->conf);
     }
 
-  iconv_close(converter);
-
  cleanup_before_return:
   if (buffer != NULL)
     g_object_unref(G_OBJECT(buffer));
@@ -835,21 +889,16 @@ build_boardlist(WorkerThread *employee, gpointer args)
 
 
 static void
-setup_boardlist(OchushaApplication *application, BBSTable *bbs_table)
+setup_boardlist(OchushaApplication *application)
 {
 #if DEBUG_GUI_MOST
   fprintf(stderr, "setup_boardlist\n");
 #endif
   boardlist_view_open(BOARDLIST_VIEW(application->boardlist_view),
-		      bbs_table->category_list, NULL,
+		      application->table->category_list, NULL,
 		      (BulletinBoardInfoNewFunc *)ensure_bulletin_board_info);
   gtk_widget_show_all(application->boardlist_view);
   gtk_widget_show_all(application->contents_window);
-  
-  if (application->bbs_table != bbs_table && application->bbs_table != NULL)
-    ochusha_bbs_table_free(application->bbs_table);
-
-  application->bbs_table = bbs_table;
 }
 
 
@@ -881,3 +930,12 @@ refresh_board_button_cb(GtkWidget *widget, OchushaApplication *application)
 #endif
   refresh_current_threadlist(application);
 }
+
+
+static void
+start_threadlist_search_button_cb(GtkWidget *widget,
+				  OchushaApplication *application)
+{
+  start_current_threadlist_search(application);
+}
+
