@@ -23,12 +23,15 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: boardlist_ui.h,v 1.2 2003/05/11 20:55:12 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_UI_H_
 #define _BOARDLIST_UI_H_
 
+#include "ochusha_bbs_thread.h"
+#include "ochusha_board_category.h"
+
 #include "ochusha_ui.h"
 
 #include "boardlist_view.h"
@@ -42,10 +45,13 @@ extern "C" {
  */
 void initialize_boardlist(OchushaApplication *application);
 void refresh_boardlist(OchushaApplication *application);
+void refresh_boardlist2(OchushaApplication *application);
 void finalize_boardlist(OchushaApplication *application);
 
+BoardCategoryInfo *ensure_board_category_info(OchushaBoardCategory *category);
+
 void update_threadlist_entry(OchushaApplication *application,
-			     BBSThread *thread);
+			     OchushaBBSThread *thread);
 
 void open_current_board_properties(OchushaApplication *application);
 
@@ -54,6 +60,8 @@ void refresh_current_threadlist_all(OchushaApplication *application);
 void redraw_current_threadlist_all(OchushaApplication *application);
 void fix_filter_button_state(OchushaApplication *application);
 
+void start_current_threadlist_search(OchushaApplication *application);
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
