@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: boardlist_view.h,v 1.1.1.1 2003/05/10 16:34:25 fuyu Exp $
  */
 
 #ifndef _BOARDLIST_VIEW_H_
@@ -68,14 +68,14 @@ struct _BoardlistViewClass
 {
   GtkScrolledWindowClass parent_class;
 
-  void (*open_view)(BoardlistView *boardlist_view, BulletinBoard *board,
+  void (*open_view)(BoardlistView *boardlist_view, OchushaBulletinBoard *board,
 		    gboolean in_tab);
   void (*select_category)(BoardlistView *boardlist_view,
-			  BoardCategory *category);
+			  OchushaBoardCategory *category);
   void (*category_expanded)(BoardlistView *boardlist_view,
-			    BoardCategory *category);
+			    OchushaBoardCategory *category);
   void (*category_collapsed)(BoardlistView *boardlist_view,
-			     BoardCategory *category);
+			     OchushaBoardCategory *category);
 };
 
 
@@ -92,8 +92,8 @@ typedef struct _BulletinBoardInfo
 } BulletinBoardInfo;
 
 
-typedef BoardCategoryInfo *BoardCategoryInfoNewFunc(BoardCategory *category);
-typedef BulletinBoardInfo *BulletinBoardInfoNewFunc(BulletinBoard *board);
+typedef BoardCategoryInfo *BoardCategoryInfoNewFunc(OchushaBoardCategory *category);
+typedef BulletinBoardInfo *BulletinBoardInfoNewFunc(OchushaBulletinBoard *board);
 
 
 GType boardlist_view_get_type(void);
@@ -103,9 +103,9 @@ void boardlist_view_open(BoardlistView *view, GSList *category_list,
 			 BulletinBoardInfoNewFunc *board_info_factory);
 
 void boardlist_view_expand_category(BoardlistView *view,
-				    BoardCategory *category);
+				    OchushaBoardCategory *category);
 void boardlist_view_collapse_category(BoardlistView *view,
-				      BoardCategory *category);
+				      OchushaBoardCategory *category);
 
 
 #ifdef __cplusplus
