@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: bulletin_board_ui.c,v 1.4 2003/05/11 18:20:36 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,8 @@
 #include "ochusha.h"
 #include "ochusha_ui.h"
 
+#include "ochusha_thread_2ch.h"
+
 #include "bbs_thread_ui.h"
 #include "bbs_thread_view.h"
 #include "board_properties.h"
@@ -57,41 +59,42 @@
 
 
 static void open_thread_dat(WorkerThread *employee, gpointer job_args);
-static void read_thread_attributes(BBSThread *thread, GHashTable *hash_table,
-				   gpointer user_data);
 static void show_threadlist(WorkerThread *employee, gpointer args);
-static void advance_view_cb(ThreadlistView *view, BBSThread *thread,
+static void advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			    PanedNotebook *paned_notebook);
-static void toggle_mark_cb(ThreadlistView *view, BBSThread *thread,
+static void toggle_mark_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
-static void toggle_hide_cb(ThreadlistView *view, BBSThread *thread,
+static void toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
-static void mark_thread_cb(ThreadlistView *view, BBSThread *thread,
+static void mark_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   gboolean do_mark, OchushaApplication *application);
-static void thread_mouse_over_cb(ThreadlistView *view, BBSThread *thread,
+static void thread_mouse_over_cb(ThreadlistView *view,
+				 OchushaBBSThread *thread,
 				 OchushaApplication *application);
-static void thread_mouse_out_cb(ThreadlistView *view, BBSThread *thread,
+static void thread_mouse_out_cb(ThreadlistView *view, OchushaBBSThread *thread,
 				OchushaApplication *application);
 static gboolean thread_title_popup_timeout(gpointer data);
 static void thread_title_popup_show();
 static gboolean thread_title_popup_paint_window(GtkWidget *widget);
 
 static void item_view_required_cb(PanedNotebook *paned_notebook,
-				  BBSThread *thread, GtkWidget **item_view,
+				  OchushaBBSThread *thread,
+				  GtkWidget **item_view,
 				  const gchar **title, GtkWidget **tab_label,
 				  OchushaApplication *application);
 static void item_view_being_closed_cb(PanedNotebook *paned_notebook,
-				      BBSThread *thread, GtkWidget *item_view,
+				      OchushaBBSThread *thread,
+				      GtkWidget *item_view,
 				      OchushaApplication *application);
 static void item_view_closed_cb(PanedNotebook *paned_notebook,
-				BBSThread *thread, GtkWidget *item_view,
+				OchushaBBSThread *thread, GtkWidget *item_view,
 				OchushaApplication *application);
 static void page_switched_cb(PanedNotebook *paned_notebook,
 			     GtkWidget *previous_page, GtkWidget *new_page,
 			     OchushaApplication *application);
 
 static void get_current_thread(OchushaApplication *application,
-			       GtkWidget **view, BBSThread **thread,
+			       GtkWidget **view, OchushaBBSThread **thread,
 			       IconLabel **tab_label);
 static void write_response_button_cb(GtkWidget *widget,
 				     OchushaApplication *application);
@@ -139,7 +142,7 @@ static pthread_cond_t thread_list_condition;
     }
 
 
-static BBSThread *popup_thread = NULL;
+static OchushaBBSThread *popup_thread = NULL;
 static GtkWidget *title_popup_window = NULL;
 static GtkWidget *title_popup_label = NULL;
 static gint title_popup_x_pos = 0;
@@ -184,8 +187,63 @@ initialize_board_ui(OchushaApplication *application)
 }
 
 
+static void
+threadlist_read_thread_element_cb(OchushaBulletinBoard *board,
+				  OchushaBBSThread *thread,
+				  GHashTable *hash_table,
+				  gpointer user_data)
+{
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+
+  info->info.view_flags = ochusha_utils_get_attribute_int(hash_table,
+							  "view_flags");
+  info->info.view_rank = ochusha_utils_get_attribute_int(hash_table,
+							 "view_rank");
+  info->last_modified = ochusha_utils_get_attribute_string(hash_table,
+							   "last_modified");
+  info->view_ignored = ochusha_utils_get_attribute_int(hash_table,
+						       "view_ignored");
+
+  return;
+}
+
+
+#define OUTPUT_THREAD_ATTRIBUTE_INT(file, thread, attribute)		\
+  fprintf(file,								\
+	  "      <attribute name=\"" #attribute	"\">\n"			\
+	  "        <int val=\"%d\"/>\n"					\
+	  "      </attribute>\n", (thread)->attribute)
+
+#define OUTPUT_THREAD_ATTRIBUTE_STRING(file, thread, attribute)		\
+  fprintf(file,								\
+	  "      <attribute name=\"" #attribute	"\">\n"			\
+	  "        <string>%s</string>\n"				\
+	  "      </attribute>\n", (thread)->attribute)
+
+
+static void
+threadlist_write_thread_element_cb(OchushaBulletinBoard *board,
+				   OchushaBBSThread *thread,
+				   FILE *threadlist_xml, gpointer user_data)
+{
+  BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
+  ThreadlistInfo *threadlist_info;
+  if (info != NULL)
+    {
+      threadlist_info = &info->info;
+      OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, threadlist_info, view_flags);
+      OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, threadlist_info, view_rank);
+
+      if (info->last_modified != NULL)
+	OUTPUT_THREAD_ATTRIBUTE_STRING(threadlist_xml, info, last_modified);
+
+      OUTPUT_THREAD_ATTRIBUTE_INT(threadlist_xml, info, view_ignored);
+    }
+}
+
+
 BulletinBoardGUIInfo *
-ensure_bulletin_board_info(BulletinBoard *board)
+ensure_bulletin_board_info(OchushaBulletinBoard *board)
 {
   BulletinBoardGUIInfo *info;
   THREAD_LIST_LOCK
@@ -193,9 +251,14 @@ ensure_bulletin_board_info(BulletinBoard *board)
       info = (BulletinBoardGUIInfo *)board->user_data;
       if (info == NULL)
 	{
-	  info
-	    = (BulletinBoardGUIInfo *)calloc(1, sizeof(BulletinBoardGUIInfo));
+	  info = g_new0(BulletinBoardGUIInfo, 1);
 	  board->user_data = info;
+	  g_signal_connect(G_OBJECT(board), "threadlist_read_thread_element",
+			   G_CALLBACK(threadlist_read_thread_element_cb),
+			   NULL);
+	  g_signal_connect(G_OBJECT(board), "threadlist_write_thread_element",
+			   G_CALLBACK(threadlist_write_thread_element_cb),
+			   NULL);
 	}
     }
   THREAD_LIST_UNLOCK;
@@ -207,7 +270,7 @@ ensure_bulletin_board_info(BulletinBoard *board)
 typedef struct _ThreadlistJobArgs
 {
   OchushaApplication *application;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
   ThreadlistView *view;
   IconLabel *tab_label;
   gboolean increment_ignored;
@@ -215,8 +278,8 @@ typedef struct _ThreadlistJobArgs
 
 
 GtkWidget *
-open_bulletin_board(OchushaApplication *application, BulletinBoard *board,
-		    IconLabel *tab_label)
+open_bulletin_board(OchushaApplication *application,
+		    OchushaBulletinBoard *board, IconLabel *tab_label)
 {
   GtkWidget *paned_notebook;
 
@@ -349,9 +412,12 @@ open_bulletin_board(OchushaApplication *application, BulletinBoard *board,
 
       info->is_busy = TRUE;
       info->subject_txt_buffer
-	= ochusha_read_subject_txt(&application->conf, board,
-				   info->last_modified,
-				   &icon_indicator_funcs, tab_label);
+	= ochusha_bulletin_board_get_threadlist_source(board,
+						&application->conf,
+						info->last_modified,
+						OCHUSHA_CACHE_TRY_REFRESH,
+						&icon_indicator_funcs,
+						tab_label);
 
       /* Ȥޤǳ */
       g_object_ref(G_OBJECT(tab_label));
@@ -369,22 +435,24 @@ open_bulletin_board(OchushaApplication *application, BulletinBoard *board,
 }
 
 
+/*
+ * ޤĤ򳫤δλԤäƥ򳫤
+ */
 typedef struct _OpenThreadJobArgs
 {
   OchushaApplication *application;
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
+  OchushaBBSThread *thread;
   char *dat_filename;
   int res_num;
   gboolean in_tab;
 } OpenThreadJobArgs;
 
 
-/*
- * ޤĤ򳫤δλԤäƥ򳫤
- */
 void
-ochusha_open_thread(OchushaApplication *application, BulletinBoard *board,
-		    const char *dat_filename, int res_num, gboolean in_tab)
+ochusha_open_thread(OchushaApplication *application,
+		    OchushaBulletinBoard *board, OchushaBBSThread *thread,
+		    char *dat_filename, int res_num, gboolean in_tab)
 {
   WorkerJob *job;
   OpenThreadJobArgs *args;
@@ -392,13 +460,13 @@ ochusha_open_thread(OchushaApplication *application, BulletinBoard *board,
   if (board == NULL)
     return;
 
-#if DEBUG_GUI_MOST
-  fprintf(stderr, "dat_filename=%s, res_num=%d\n", dat_filename, res_num);
-#endif
-
   paned_notebook_open_item_view(PANED_NOTEBOOK(application->contents_window),
 				board, in_tab);
-  /* Ĥ򳫤Τ̥åɤǹԤΤǴλԤΥåɤäƹԤ */
+  /*
+   * Ĥ򳫤Τ̥åɤǹԤǽꡢ
+   * Ǥϡ򳫤ΤϤθˤʤΤǡĤΤλ
+   * Ԥθ她򳫤ΥåɤȤ
+   */
   job = (WorkerJob *)calloc(1, sizeof(WorkerJob));
   args = (OpenThreadJobArgs *)calloc(1, sizeof(OpenThreadJobArgs));
   if (job == NULL || args == NULL)
@@ -415,7 +483,8 @@ ochusha_open_thread(OchushaApplication *application, BulletinBoard *board,
 
   args->application = application;
   args->board = board;
-  args->dat_filename = strdup(dat_filename);
+  args->thread = thread;
+  args->dat_filename = dat_filename;
   args->res_num = res_num;
   args->in_tab = in_tab;
   commit_job(job);
@@ -427,12 +496,12 @@ open_thread_dat(WorkerThread *employee, gpointer job_args)
 {
   OpenThreadJobArgs *args = (OpenThreadJobArgs *)job_args;
   OchushaApplication *application = args->application;
-  BulletinBoard *board = args->board;
+  OchushaBulletinBoard *board = args->board;
 
   THREAD_LIST_LOCK
     {
       PanedNotebook *board_view;
-      BBSThread *thread;
+      OchushaBBSThread *thread;
       BulletinBoardGUIInfo *info = (BulletinBoardGUIInfo *)board->user_data;
       if (info->is_busy)
 	THREAD_LIST_COND_WAIT;
@@ -463,7 +532,8 @@ open_thread_dat(WorkerThread *employee, gpointer job_args)
 
 
 void
-refresh_threadlist_view(OchushaApplication *application, BulletinBoard *board)
+refresh_threadlist_view(OchushaApplication *application,
+			OchushaBulletinBoard *board)
 {
   PanedNotebook *contents_window;
   ThreadlistView *threadlist_view;
@@ -486,7 +556,7 @@ refresh_threadlist_view(OchushaApplication *application, BulletinBoard *board)
   THREAD_LIST_LOCK
     {
       BulletinBoardGUIInfo *info = (BulletinBoardGUIInfo *)board->user_data;
-      AsyncBuffer *old_buffer;
+      OchushaAsyncBuffer *old_buffer;
       if (info->is_busy)
 	{
 	  THREAD_LIST_UNLOCK;
@@ -497,10 +567,14 @@ refresh_threadlist_view(OchushaApplication *application, BulletinBoard *board)
 	}
 
       old_buffer = info->subject_txt_buffer;
+
       info->subject_txt_buffer
-	= ochusha_read_subject_txt(&application->conf, board,
-				   info->last_modified,
-				   &icon_indicator_funcs, tab_label);
+	= ochusha_bulletin_board_get_threadlist_source(board,
+						&application->conf,
+						info->last_modified,
+						OCHUSHA_CACHE_TRY_REFRESH,
+						&icon_indicator_funcs,
+						tab_label);
       if (info->subject_txt_buffer == NULL)
 	{
 	  info->subject_txt_buffer = old_buffer;
@@ -546,7 +620,8 @@ refresh_threadlist_view(OchushaApplication *application, BulletinBoard *board)
 
 
 void
-redraw_threadlist_view(OchushaApplication *application, BulletinBoard *board)
+redraw_threadlist_view(OchushaApplication *application,
+		       OchushaBulletinBoard *board)
 {
   PanedNotebook *contents_window;
   ThreadlistView *threadlist_view;
@@ -615,31 +690,6 @@ redraw_threadlist_view(OchushaApplication *application, BulletinBoard *board)
 }
 
 
-static void
-read_thread_attributes(BBSThread *thread, GHashTable *hash_table,
-		       gpointer user_data)
-{
-#if 0
-  ThreadlistView *view = (ThreadlistView *)user_data;
-#endif
-  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
-
-  info->info.view_flags = get_attribute_int(hash_table, "view_flags");
-  info->info.view_rank = get_attribute_int(hash_table, "view_rank");
-  info->last_modified = get_attribute_string(hash_table, "last_modified");
-  info->view_ignored = get_attribute_int(hash_table, "view_ignored");
-
-#if DEBUG_GUI_MOST
-  {
-    gchar *title = convert_string(utf8_to_native, thread->title, -1);
-    fprintf(stderr, "read_thread_attributes: %s\n", title);
-    free(title);
-  }
-#endif
-  return;
-}
-
-
 typedef struct _EachThreadArgs
 {
   OchushaApplication *application;
@@ -652,7 +702,7 @@ typedef struct _EachThreadArgs
 
 
 static gboolean
-each_thread_cb(BBSThread *thread, gpointer user_data)
+each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
 {
   EachThreadArgs *args = (EachThreadArgs *)user_data;
   ThreadlistView *view = args->view;
@@ -701,11 +751,10 @@ show_threadlist(WorkerThread *employee, gpointer args)
 {
   ThreadlistJobArgs *job_args = (ThreadlistJobArgs *)args;
   OchushaApplication *application = job_args->application;
-  BulletinBoard *board = job_args->board;
+  OchushaBulletinBoard *board = job_args->board;
   BulletinBoardGUIInfo *info = (BulletinBoardGUIInfo *)board->user_data;
   ThreadlistView *view = job_args->view;
-  AsyncBuffer *buffer;
-  iconv_t to_utf8;
+  OchushaAsyncBuffer *buffer;
   EachThreadArgs cb_args =
     {
       application,
@@ -723,8 +772,7 @@ show_threadlist(WorkerThread *employee, gpointer args)
 #endif
 
   if (board->thread_list == NULL)
-    ochusha_read_threadlist_xml(&application->conf, board,
-				read_thread_attributes, view);
+    ochusha_bulletin_board_read_threadlist_xml(board, &application->conf);
 
   THREAD_LIST_LOCK
     {
@@ -738,19 +786,6 @@ show_threadlist(WorkerThread *employee, gpointer args)
       gchar *name = convert_string(utf8_to_native, board->name, -1);
       fprintf(stderr, "Couldn't get thread list (subject.txt) for %s\n", name);
       free(name);
-#endif
-      to_utf8 = (iconv_t)-1;
-      goto finish_job;
-    }
-
-  to_utf8 = iconv_open("UTF-8//IGNORE", "CP932");
-  if (to_utf8 == (iconv_t)-1)
-    {
-#if DEBUG_GUI_MOST
-      gchar *name = convert_string(utf8_to_native, board->name, -1);
-      fprintf(stderr, "iconv_open() failed.\n");
-      fprintf(stderr, "Couldn't get thread list (subject.txt) for %s\n", name);
-      free(name);
 #endif
       goto finish_job;
     }
@@ -767,8 +802,8 @@ show_threadlist(WorkerThread *employee, gpointer args)
     }
   gdk_threads_leave();
 
-  if (!ochusha_analyze_subject_txt(board, buffer, to_utf8,
-				   each_thread_cb, &cb_args))
+  if (!ochusha_bulletin_board_refresh_threadlist(board, buffer,
+						 each_thread_cb, &cb_args))
     {
 #if DEBUG_GUI_MOST
       gchar *name = convert_string(utf8_to_native, board->name, -1);
@@ -780,7 +815,7 @@ show_threadlist(WorkerThread *employee, gpointer args)
       gdk_threads_leave();
       goto finish_job;
     }
-
+  
 #if DEBUG_GUI_MOST
   fprintf(stderr, "Updating threadlist.\n");
 #endif
@@ -791,7 +826,8 @@ show_threadlist(WorkerThread *employee, gpointer args)
 
  finish_job:
 #if DEBUG_ASYNC_BUFFER_MOST
-  fprintf(stderr, "show_threadlist: unref AsyncBuffer(0x%x)\n", (int)buffer);
+  fprintf(stderr, "show_threadlist: unref OchushaAsyncBuffer(0x%x)\n",
+	  (int)buffer);
   fprintf(stderr, "* before unref: buffer->ref_count=%d\n",
 	  G_OBJECT(buffer)->ref_count);
 #endif
@@ -826,8 +862,6 @@ show_threadlist(WorkerThread *employee, gpointer args)
     g_object_unref(G_OBJECT(job_args->tab_label));
   gdk_threads_leave();
 
-  if (to_utf8 != (iconv_t)-1)
-    iconv_close(to_utf8);
   if (buffer != NULL)
     g_object_unref(G_OBJECT(buffer));
 
@@ -835,11 +869,11 @@ show_threadlist(WorkerThread *employee, gpointer args)
 }
 
 
-AsyncBuffer *
-snatch_subject_txt_buffer_for_board(BulletinBoard *board)
+OchushaAsyncBuffer *
+snatch_subject_txt_buffer_for_board(OchushaBulletinBoard *board)
 {
   BulletinBoardGUIInfo *info = (BulletinBoardGUIInfo *)board->user_data;
-  AsyncBuffer *buffer;
+  OchushaAsyncBuffer *buffer;
 
   THREAD_LIST_LOCK
     {
@@ -855,7 +889,7 @@ snatch_subject_txt_buffer_for_board(BulletinBoard *board)
 
 void
 update_threadlist_entry_style(OchushaApplication *application,
-			      ThreadlistView *view, BBSThread *thread)
+			      ThreadlistView *view, OchushaBBSThread *thread)
 {
   BulletinBoardGUIInfo *board_info
     = (BulletinBoardGUIInfo *)thread->board->user_data;
@@ -873,7 +907,7 @@ update_threadlist_entry_style(OchushaApplication *application,
 
 
 static void
-advance_view_cb(ThreadlistView *view, BBSThread *thread,
+advance_view_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		PanedNotebook *paned_notebook)
 {
   if (paned_notebook_get_current_item(paned_notebook) != thread)
@@ -888,7 +922,7 @@ advance_view_cb(ThreadlistView *view, BBSThread *thread,
 
 
 static void
-toggle_mark_cb(ThreadlistView *view, BBSThread *thread,
+toggle_mark_cb(ThreadlistView *view, OchushaBBSThread *thread,
 	       OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
@@ -898,7 +932,7 @@ toggle_mark_cb(ThreadlistView *view, BBSThread *thread,
 
 
 static void
-toggle_hide_cb(ThreadlistView *view, BBSThread *thread,
+toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 	       OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
@@ -908,7 +942,7 @@ toggle_hide_cb(ThreadlistView *view, BBSThread *thread,
 
 
 static void
-mark_thread_cb(ThreadlistView *view, BBSThread *thread, gboolean do_mark,
+mark_thread_cb(ThreadlistView *view, OchushaBBSThread *thread, gboolean do_mark,
 	       OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
@@ -921,7 +955,7 @@ mark_thread_cb(ThreadlistView *view, BBSThread *thread, gboolean do_mark,
 
 
 static void
-thread_mouse_over_cb(ThreadlistView *view, BBSThread *thread,
+thread_mouse_over_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		     OchushaApplication *application)
 {
   if (!application->enable_popup_title)
@@ -948,7 +982,7 @@ thread_mouse_over_cb(ThreadlistView *view, BBSThread *thread,
 
 
 static void
-thread_mouse_out_cb(ThreadlistView *view, BBSThread *thread,
+thread_mouse_out_cb(ThreadlistView *view, OchushaBBSThread *thread,
 		    OchushaApplication *application)
 {
 #if DEBUG_GUI
@@ -1032,7 +1066,7 @@ thread_title_popup_paint_window(GtkWidget *widget)
 
 static void
 item_view_required_cb(PanedNotebook *paned_notebook,
-		      BBSThread *thread, GtkWidget **item_view,
+		      OchushaBBSThread *thread, GtkWidget **item_view,
 		      const gchar **title, GtkWidget **tab_label,
 		      OchushaApplication *application)
 {
@@ -1044,12 +1078,13 @@ item_view_required_cb(PanedNotebook *paned_notebook,
 
 
 static void
-free_dat_buffer(BBSThread *thread, gpointer unused)
+free_dat_buffer(OchushaBBSThread *thread, gpointer unused)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
 
 #if DEBUG_ASYNC_BUFFER_MOST
-  fprintf(stderr, "free_dat_buffer: unref AsyncBuffer(0x%x)\n", (int)info->dat_buffer);
+  fprintf(stderr, "free_dat_buffer: unref OchushaAsyncBuffer(0x%x)\n",
+	  (int)info->dat_buffer);
   fprintf(stderr, "* before unref: dat_buffer->ref_count=%d\n",
 	  G_OBJECT(info->dat_buffer)->ref_count);
 #endif
@@ -1062,12 +1097,12 @@ free_dat_buffer(BBSThread *thread, gpointer unused)
 
 
 static void
-item_view_being_closed_cb(PanedNotebook *paned_notebook, BBSThread *thread,
+item_view_being_closed_cb(PanedNotebook *paned_notebook, OchushaBBSThread *thread,
 			  GtkWidget *item_view,
 			  OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
-  AsyncBuffer *buffer = info->dat_buffer;
+  OchushaAsyncBuffer *buffer = info->dat_buffer;
 
   /*
    * XXX: Ǥinfo->bufferοǤthread safetyݤǤƤʤ
@@ -1102,9 +1137,9 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook, BBSThread *thread,
     {
       gdk_threads_leave();
 
-      async_buffer_suspend(buffer);
-      async_buffer_terminate(buffer);
-      async_buffer_resume(buffer);
+      ochusha_async_buffer_suspend(buffer);
+      ochusha_async_buffer_terminate(buffer);
+      ochusha_async_buffer_resume(buffer);
 
       gdk_threads_enter();
     }
@@ -1120,23 +1155,23 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook, BBSThread *thread,
 
   gdk_threads_leave();
 
-  async_buffer_suspend_all();
+  ochusha_async_buffer_suspend_all();
 
   if (info->dat_buffer != NULL)
-    async_buffer_terminate(info->dat_buffer);
+    ochusha_async_buffer_terminate(info->dat_buffer);
 
   gdk_threads_enter();
 
   while (gtk_events_pending())
     gtk_main_iteration();
 
-  async_buffer_resume_all();
+  ochusha_async_buffer_resume_all();
 #endif
 }
 
 
 static void
-item_view_closed_cb(PanedNotebook *paned_notebook, BBSThread *thread,
+item_view_closed_cb(PanedNotebook *paned_notebook, OchushaBBSThread *thread,
 		    GtkWidget *item_view, OchushaApplication *application)
 {
   BBSThreadGUIInfo *info = (BBSThreadGUIInfo *)thread->user_data;
@@ -1162,7 +1197,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
 		 OchushaApplication *application)
 {
   ThreadlistView *threadlist_view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   BBSThreadGUIInfo *info;
 #if DEBUG_GUI_MOST
   fprintf(stderr, "bulletin_board_ui.c: page_switched_cb\n");
@@ -1174,7 +1209,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
    */
   if (previous_page != NULL)
     {
-      thread = (BBSThread *)paned_notebook_get_item(paned_notebook,
+      thread = (OchushaBBSThread *)paned_notebook_get_item(paned_notebook,
 						    previous_page);
       bbs_thread_view_place_cursor_onscreen(BBS_THREAD_VIEW(previous_page));
       if (thread != NULL)
@@ -1187,7 +1222,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
 #if ENABLE_MAIN_TOOLBAR
   {
     gchar pseudo_url[PATH_MAX];
-    BBSThread *thread = paned_notebook_get_item(paned_notebook, new_page);
+    OchushaBBSThread *thread = paned_notebook_get_item(paned_notebook, new_page);
     if (thread == NULL)
       set_current_url(application, "empty");
     else
@@ -1208,14 +1243,15 @@ page_switched_cb(PanedNotebook *paned_notebook,
   info = (BBSThreadGUIInfo *)thread->user_data;
   if (info->next_mark != NULL)
     bbs_thread_view_scroll_to_mark(BBS_THREAD_VIEW(new_page), info->next_mark);
-    
-  threadlist_view_scroll_to_thread(threadlist_view, thread);
+
+  if (application->show_threadlist_entry_when_thread_selected)
+    threadlist_view_scroll_to_thread(threadlist_view, thread);
 }
 
 
 static void
 get_current_thread(OchushaApplication *application,
-		   GtkWidget **view, BBSThread **thread, IconLabel **tab_label)
+		   GtkWidget **view, OchushaBBSThread **thread, IconLabel **tab_label)
 {
   PanedNotebook *paned_notebook;
 
@@ -1231,7 +1267,7 @@ get_current_thread(OchushaApplication *application,
     }
 
   *view = paned_notebook_get_current_item_view(paned_notebook);
-  *thread = (BBSThread *)paned_notebook_get_current_item(paned_notebook);
+  *thread = (OchushaBBSThread *)paned_notebook_get_current_item(paned_notebook);
   if (tab_label != NULL)
     *tab_label = (IconLabel *)paned_notebook_get_tab_label(paned_notebook,
 							   *thread);
@@ -1239,7 +1275,7 @@ get_current_thread(OchushaApplication *application,
 
 
 void
-finalize_bulletin_board_view(BulletinBoard *board, GtkWidget *widget)
+finalize_bulletin_board_view(OchushaBulletinBoard *board, GtkWidget *widget)
 {
   PanedNotebook *board_view;
 
@@ -1264,25 +1300,22 @@ void
 write_response(OchushaApplication *application)
 {
   GtkWidget *view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   IconLabel *tab_label;
-  char url[PATH_MAX];
 
   get_current_thread(application, &view, &thread, &tab_label);
   if (view == NULL || thread == NULL)
     return;
 
-  /*
-   * TODO: ǽ񤭤ޤ礦
-   */
-  if (snprintf(url, PATH_MAX, "http://%s/%sl5", thread->board->server, thread->pseudo_path)
-      < PATH_MAX)
-    {
-#if DEBUG_GUI
-      fprintf(stderr, "URL: %s\n", url);
-#endif
-      ochusha_open_url(application, url, FALSE, TRUE);
-    }
+  {
+    /*
+     * TODO: ǽ񤭹ߤޤ礦
+     */
+    char url[PATH_MAX];
+    snprintf(url, PATH_MAX, "%sl10",
+	     ochusha_bbs_thread_get_thread_url(thread));
+    ochusha_open_url(application, url, FALSE, TRUE);
+  }
 }
 
 
@@ -1290,7 +1323,7 @@ void
 refresh_current_thread(OchushaApplication *application)
 {
   GtkWidget *view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   IconLabel *tab_label;
   get_current_thread(application, &view, &thread, &tab_label);
   if (view == NULL || thread == NULL)
@@ -1317,7 +1350,7 @@ void
 jump_to_new_comer_response_of_current_thread(OchushaApplication *application)
 {
   GtkWidget *view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   get_current_thread(application, &view, &thread, NULL);
   if (view == NULL || thread == NULL)
     return;
@@ -1336,7 +1369,7 @@ void
 go_to_the_last_response_of_current_thread(OchushaApplication *application)
 {
   GtkWidget *view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   get_current_thread(application, &view, &thread, NULL);
   if (view == NULL || thread == NULL)
     return;
@@ -1355,7 +1388,7 @@ void
 go_to_the_first_response_of_current_thread(OchushaApplication *application)
 {
   GtkWidget *view;
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   get_current_thread(application, &view, &thread, NULL);
   if (view == NULL || thread == NULL)
     return;
