@@ -23,13 +23,13 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: bulletin_board_ui.h,v 1.1.1.1 2003/05/10 16:34:25 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
 #define _BULLETIN_BOARD_UI_H_
 
-#include "asyncbuf.h"
+#include "ochusha_async_buffer.h"
 
 #include "ochusha.h"
 #include "ochusha_ui.h"
@@ -51,7 +51,7 @@ typedef struct _BulletinBoardGUIInfo
 {
   BulletinBoardInfo info;
 
-  AsyncBuffer *subject_txt_buffer;
+  OchushaAsyncBuffer *subject_txt_buffer;
 
   GtkWidget *properties_dialog;
 
@@ -66,22 +66,25 @@ typedef struct _BulletinBoardGUIInfo
 
 void initialize_board_ui(OchushaApplication *application);
 
-BulletinBoardGUIInfo *ensure_bulletin_board_info(BulletinBoard *board);
+BulletinBoardGUIInfo *ensure_bulletin_board_info(OchushaBulletinBoard *board);
 GtkWidget *open_bulletin_board(OchushaApplication *application,
-			       BulletinBoard *board, IconLabel *tab_label);
-void finalize_bulletin_board_view(BulletinBoard *board, GtkWidget *widget);
+			       OchushaBulletinBoard *board,
+			       IconLabel *tab_label);
+void finalize_bulletin_board_view(OchushaBulletinBoard *board,
+				  GtkWidget *widget);
 
-void ochusha_open_thread(OchushaApplication *application, BulletinBoard *board,
-			 const char *dat_filename, int res_num,
-			 gboolean in_tab);
+void ochusha_open_thread(OchushaApplication *application,
+			 OchushaBulletinBoard *board, OchushaBBSThread *thread,
+			 char *dat_filename, int res_num, gboolean in_tab);
 
 void refresh_threadlist_view(OchushaApplication *application,
-			     BulletinBoard *board);
+			     OchushaBulletinBoard *board);
 void redraw_threadlist_view(OchushaApplication *application,
-			    BulletinBoard *board);
-AsyncBuffer *snatch_subject_txt_buffer_for_board(BulletinBoard *board);
+			    OchushaBulletinBoard *board);
+OchushaAsyncBuffer *snatch_subject_txt_buffer_for_board(OchushaBulletinBoard *board);
 void update_threadlist_entry_style(OchushaApplication *application,
-				   ThreadlistView *view, BBSThread *thread);
+				   ThreadlistView *view,
+				   OchushaBBSThread *thread);
 
 void refresh_current_thread(OchushaApplication *application);
 void jump_to_new_comer_response_of_current_thread(OchushaApplication *application);
