@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: main.c,v 1.1.1.1 2003/05/10 16:34:25 fuyu Exp $
  */
 
 #include "config.h"
@@ -53,7 +53,7 @@ main(int argc, char *argv[])
   OchushaApplication *application
     = (OchushaApplication *)calloc(1, sizeof(OchushaApplication));
 
-  ochusha_prepare_home(&application->conf);
+  ochusha_config_prepare_home(&application->conf);
 
   g_thread_init(NULL);
   gdk_threads_init();
@@ -68,9 +68,12 @@ main(int argc, char *argv[])
   initialize_common_converters();
   initialize_worker(INITIAL_NUM_THREADS, MAXIMUM_NUM_THREADS);
 
-  resource_file = ochusha_find_file(&application->conf, OCHUSHA_GTKRC);
+  resource_file = ochusha_config_find_file(&application->conf, OCHUSHA_GTKRC);
   if (resource_file != NULL)
-    gtk_rc_parse(resource_file);
+    {
+      gtk_rc_parse(resource_file);
+      g_free(resource_file);
+    }
 
   ochusha_init_application(application);
 
