@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: ochusha_ui.c,v 1.3 2003/05/11 18:20:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,8 @@
 #define OCHUSHA_UI_PRIVATE
 #include "ochusha_ui.h"
 
+#include "ochusha_utils_2ch.h"
+
 #include "bbs_thread_ui.h"
 #include "boardlist_ui.h"
 #include "bulletin_board_ui.h"
@@ -395,13 +397,17 @@ void
 ochusha_open_url(OchushaApplication *application, const gchar *url,
 		 gboolean in_tab, gboolean use_web_browser)
 {
-  BulletinBoard *board;
+  OchushaBulletinBoard *board;
+  OchushaBBSThread *thread;
+  unsigned int thread_num;
+  unsigned int from;
+  unsigned int to;
   char dat_filename[PATH_MAX];
-  char *path;
 
   if (use_web_browser
-      || !ochusha_bbs_table_parse_url_2ch(application->bbs_table, url,
-					  &board, &path))
+      || !ochusha_utils_2ch_parse_url(application->table, url,
+				      &board, &thread_num, &thread,
+				      &from, &to, NULL))
     {
       /* TODO: Υ֥֥饦ɽ */
       char command_line[COMMAND_LINE_BUFFER_SIZE];
@@ -420,25 +426,8 @@ ochusha_open_url(OchushaApplication *application, const gchar *url,
       return;
     }
 
-  if (snprintf(dat_filename, PATH_MAX, "%s", path) < PATH_MAX)
-    {
-      char *tmp_pos = strchr(dat_filename, '/');
-      int res_num = 0;
-      if (tmp_pos != NULL)
-	{
-	  sscanf(tmp_pos + 1, "%d", &res_num);
-	  *tmp_pos = '\0';
-	}
-
-      if (g_strlcat(dat_filename, ".dat", PATH_MAX) < PATH_MAX)
-	{
-	  ochusha_open_thread(application,
-			      board, dat_filename, res_num, in_tab);
-	}
-    }
-
-  if (path != NULL)
-    free(path);
+  snprintf(dat_filename, PATH_MAX, "%d.dat", thread_num);
+  ochusha_open_thread(application, board, thread, dat_filename, from, in_tab);
 }
 
 
@@ -667,6 +656,8 @@ write_optional_prefs(FILE *file, gpointer user_data)
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, thread_tab_minimum_size);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  thread_tab_enable_tooltips);
+  OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
+				  show_threadlist_entry_when_thread_selected);
 
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, enable_popup_title);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, popup_title_delay);
@@ -675,6 +666,8 @@ write_optional_prefs(FILE *file, gpointer user_data)
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, popup_response_delay);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application,
 				  enable_smart_popup_placement);
+  OUTPUT_CONFIG_ATTRIBUTE_INT(file, application,
+			      maximum_number_of_popup_responses);
 
   OUTPUT_CONFIG_ATTRIBUTE_STRING(file, application, web_browser_template);
 
@@ -689,31 +682,40 @@ write_optional_prefs(FILE *file, gpointer user_data)
 static void
 configure_application(OchushaApplication *application)
 {
-  ochusha_read_config_xml(&application->conf, read_optional_prefs, application);
+  ochusha_read_config_xml(&application->conf, read_optional_prefs,
+			  application);
   /* Sets unspecified attributes */
   if (application->width == 0)
-    application->width = OCHUSHA_DEFAULT_WIDTH;
+    {
+      application->width = OCHUSHA_DEFAULT_WIDTH;
+      application->height = OCHUSHA_DEFAULT_HEIGHT;
+      application->boardlist_width = OCHUSHA_DEFAULT_BOARDLIST_WIDTH;
+      application->threadlist_height = OCHUSHA_DEFAULT_THREADLIST_HEIGHT;
 
-  if (application->height == 0)
-    application->height = OCHUSHA_DEFAULT_HEIGHT;
+      application->boardlist_pane_style = HPANED_STYLE;
+      application->threadlist_pane_style = VPANED_STYLE;
+
+      application->maximum_number_of_popup_responses
+	= OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES;
+
+      application->popup_response_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
+      application->show_threadlist_entry_when_thread_selected
+	= OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED;
+    }
 
-  if (application->boardlist_width == 0)
-    application->boardlist_width = OCHUSHA_DEFAULT_BOARDLIST_WIDTH;
   if (application->board_tab_minimum_size == 0)
     application->board_tab_minimum_size
       = OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE;
 
-  if (application->threadlist_height == 0)
-    application->threadlist_height = OCHUSHA_DEFAULT_THREADLIST_HEIGHT;
   if (application->thread_tab_minimum_size == 0)
     application->thread_tab_minimum_size
       = OCHUSHA_DEFAULT_THREAD_TAB_MINIMUM_SIZE;
 
   if (application->popup_title_delay == 0)
-    application->popup_title_delay = 500;
+    application->popup_title_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
 
   if (application->web_browser_template == NULL)
-    application->web_browser_template = strdup("mozilla -raise -remote \"openURL(%s,new-window)\"");
+    application->web_browser_template = g_strdup("mozilla -raise -remote \"openURL(%s,new-window)\"");
 }
 
 
@@ -722,38 +724,40 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
 {
   OchushaApplication *application = (OchushaApplication *)user_data;
 
-  application->width = get_attribute_int(pref_attrs, "width");
+  application->width = ochusha_utils_get_attribute_int(pref_attrs, "width");
 
-  application->height = get_attribute_int(pref_attrs, "height");
+  application->height = ochusha_utils_get_attribute_int(pref_attrs, "height");
 
   application->boardlist_width
-    = get_attribute_int(pref_attrs, "boardlist_width");
+    = ochusha_utils_get_attribute_int(pref_attrs, "boardlist_width");
 
   application->threadlist_height
-    = get_attribute_int(pref_attrs, "threadlist_height");
+    = ochusha_utils_get_attribute_int(pref_attrs, "threadlist_height");
 
   if (g_hash_table_lookup(pref_attrs, "boardlist_pane_style") != NULL)
     application->boardlist_pane_style
-      = get_attribute_int(pref_attrs, "boardlist_pane_style");
+      = ochusha_utils_get_attribute_int(pref_attrs, "boardlist_pane_style");
   else
     application->boardlist_pane_style = HPANED_STYLE;
 
   if (g_hash_table_lookup(pref_attrs, "board_tab_shrinkable") != NULL)
     application->board_tab_shrinkable
-      = get_attribute_boolean(pref_attrs, "board_tab_shrinkable");
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "board_tab_shrinkable");
   else
     application->board_tab_shrinkable = OCHUSHA_DEFAULT_BOARD_TAB_SHRINKABLE;
 
   if (g_hash_table_lookup(pref_attrs, "board_tab_minimum_size") != NULL)
     application->board_tab_minimum_size
-      = get_attribute_int(pref_attrs, "board_tab_minimum_size");
+      = ochusha_utils_get_attribute_int(pref_attrs, "board_tab_minimum_size");
   else
     application->board_tab_minimum_size
       = OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE;
 
   if (g_hash_table_lookup(pref_attrs, "board_tab_enable_tooltips") != NULL)
     application->board_tab_enable_tooltips
-      = get_attribute_boolean(pref_attrs, "board_tab_enable_tooltips");
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "board_tab_enable_tooltips");
   else
     application->board_tab_enable_tooltips
       = OCHUSHA_DEFAULT_BOARD_TAB_ENABLE_TOOLTIPS;
@@ -761,63 +765,91 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
 
   if (g_hash_table_lookup(pref_attrs, "threadlist_pane_style") != NULL)
     application->threadlist_pane_style
-      = get_attribute_int(pref_attrs, "threadlist_pane_style");
+      = ochusha_utils_get_attribute_int(pref_attrs, "threadlist_pane_style");
   else
     application->threadlist_pane_style = VPANED_STYLE;
 
   if (g_hash_table_lookup(pref_attrs, "thread_tab_shrinkable") != NULL)
     application->thread_tab_shrinkable
-      = get_attribute_boolean(pref_attrs, "thread_tab_shrinkable");
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "thread_tab_shrinkable");
   else
     application->thread_tab_shrinkable = OCHUSHA_DEFAULT_THREAD_TAB_SHRINKABLE;
 
   if (g_hash_table_lookup(pref_attrs, "thread_tab_minimum_size") != NULL)
     application->thread_tab_minimum_size
-      = get_attribute_int(pref_attrs, "thread_tab_minimum_size");
+      = ochusha_utils_get_attribute_int(pref_attrs, "thread_tab_minimum_size");
   else
     application->thread_tab_minimum_size
       = OCHUSHA_DEFAULT_THREAD_TAB_MINIMUM_SIZE;
 
   if (g_hash_table_lookup(pref_attrs, "thread_tab_enable_tooltips") != NULL)
     application->thread_tab_enable_tooltips
-      = get_attribute_boolean(pref_attrs, "thread_tab_enable_tooltips");
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "thread_tab_enable_tooltips");
   else
     application->thread_tab_enable_tooltips
       = OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS;
 
+  if (g_hash_table_lookup(pref_attrs,
+			  "show_threadlist_entry_when_thread_selected")
+      != NULL)
+    application->show_threadlist_entry_when_thread_selected
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+				"show_threadlist_entry_when_thread_selected");
+  else
+    application->show_threadlist_entry_when_thread_selected
+      = OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED;
+
 
   if (g_hash_table_lookup(pref_attrs, "enable_popup_title") != NULL)
     application->enable_popup_title
-      = get_attribute_boolean(pref_attrs, "enable_popup_title");
+      = ochusha_utils_get_attribute_boolean(pref_attrs, "enable_popup_title");
   else
     application->enable_popup_title = FALSE;
 
   application->popup_title_delay
-    = get_attribute_int(pref_attrs, "popup_title_delay");
+    = ochusha_utils_get_attribute_int(pref_attrs, "popup_title_delay");
 
   if (g_hash_table_lookup(pref_attrs, "enable_popup_response") != NULL)
     application->enable_popup_response
-      = get_attribute_boolean(pref_attrs, "enable_popup_response");
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "enable_popup_response");
   else
     application->enable_popup_response = TRUE;
 
-  application->popup_response_delay
-    = get_attribute_int(pref_attrs, "popup_response_delay");
+  if (g_hash_table_lookup(pref_attrs, "popup_response_delay") != NULL)
+    application->popup_response_delay
+      = ochusha_utils_get_attribute_int(pref_attrs, "popup_response_delay");
+  else
+    application->popup_response_delay = OCHUSHA_DEFAULT_POPUP_DELAY;
 
   if (g_hash_table_lookup(pref_attrs, "enable_smart_popup_placement") != NULL)
     application->enable_smart_popup_placement
-      = get_attribute_boolean(pref_attrs, "enable_smart_popup_placement");
+      = ochusha_utils_get_attribute_boolean(pref_attrs,
+					    "enable_smart_popup_placement");
   else
     application->enable_smart_popup_placement = TRUE;
 
+  if (g_hash_table_lookup(pref_attrs, "maximum_number_of_popup_responses")
+      != NULL)
+    application->maximum_number_of_popup_responses
+      = ochusha_utils_get_attribute_int(pref_attrs,
+					"maximum_number_of_popup_responses");
+  else
+    application->maximum_number_of_popup_responses
+      = OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES;
+
   application->web_browser_template
-    = get_attribute_string(pref_attrs, "web_browser_template");
+    = ochusha_utils_get_attribute_string(pref_attrs, "web_browser_template");
 
   application->user_default_filter.rule
-    = get_attribute_string(pref_attrs, "user_default_filter.rule");
+    = ochusha_utils_get_attribute_string(pref_attrs,
+					 "user_default_filter.rule");
 
   application->user_default_filter.ignore_threshold
-    = get_attribute_int(pref_attrs, "user_default_filter.ignore_threshold");
+    = ochusha_utils_get_attribute_int(pref_attrs,
+				      "user_default_filter.ignore_threshold");
 }
 
 
