@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: ochusha_ui.h,v 1.3 2003/05/11 18:20:37 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -31,6 +31,8 @@
 
 #include "ochusha.h"
 #include "ochusha_private.h"
+#include "ochusha_bbs_table.h"
+
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -44,20 +46,25 @@
 #define DEBUG_WIDGET		0
 #define DEBUG_WIDGET_MOST	0
 
-#define ENABLE_MAIN_TOOLBAR				0
+#define ENABLE_MAIN_TOOLBAR						0
 
-#define OCHUSHA_DEFAULT_WIDTH				600
-#define OCHUSHA_DEFAULT_HEIGHT				400
-#define OCHUSHA_DEFAULT_BOARDLIST_WIDTH			150
-#define OCHUSHA_DEFAULT_THREADLIST_HEIGHT		100
+#define OCHUSHA_DEFAULT_WIDTH						600
+#define OCHUSHA_DEFAULT_HEIGHT						400
+#define OCHUSHA_DEFAULT_BOARDLIST_WIDTH					150
+#define OCHUSHA_DEFAULT_THREADLIST_HEIGHT				100
 
-#define OCHUSHA_DEFAULT_BOARD_TAB_SHRINKABLE		FALSE
-#define OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE		80
-#define OCHUSHA_DEFAULT_BOARD_TAB_ENABLE_TOOLTIPS	FALSE
+#define OCHUSHA_DEFAULT_BOARD_TAB_SHRINKABLE				FALSE
+#define OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE				80
+#define OCHUSHA_DEFAULT_BOARD_TAB_ENABLE_TOOLTIPS			FALSE
+
+#define OCHUSHA_DEFAULT_THREAD_TAB_SHRINKABLE				TRUE
+#define OCHUSHA_DEFAULT_THREAD_TAB_MINIMUM_SIZE				80
+#define OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS			TRUE
+#define OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED	FALSE
+
+#define OCHUSHA_DEFAULT_POPUP_DELAY					500
+#define OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES		5
 
-#define OCHUSHA_DEFAULT_THREAD_TAB_SHRINKABLE		TRUE
-#define OCHUSHA_DEFAULT_THREAD_TAB_MINIMUM_SIZE		80
-#define OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS	TRUE
 
 
 #define OCHUSHA_GTKRC				"ochusha-gtkrc"
@@ -122,8 +129,7 @@ struct _OchushaApplication
 
 
   /* İθǡ */
-  BBSTable *bbs_table;
-
+  OchushaBBSTable *table;
 
   /* windowʤ */
   gint width;
@@ -142,6 +148,7 @@ struct _OchushaApplication
   gboolean thread_tab_shrinkable;
   guint thread_tab_minimum_size;
   gboolean thread_tab_enable_tooltips;
+  gboolean show_threadlist_entry_when_thread_selected;
 
 
   /* 쥿Υݥåץå״Ϣ */
@@ -153,6 +160,7 @@ struct _OchushaApplication
   gboolean enable_popup_response;
   guint popup_response_delay;
   gboolean enable_smart_popup_placement;
+  gint maximum_number_of_popup_responses;
 
 
   /* ֥֥饦Υޥɥ饤ƥץ졼 */
