@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: threadlist_filter.c,v 1.1.1.1 2003/05/10 16:34:26 fuyu Exp $
  */
 
 #include "ochusha.h"
@@ -1548,7 +1548,7 @@ setup_default_threadlist_filter(OchushaApplication *application)
 gboolean
 threadlist_filter_check_thread(ThreadlistFilter *filter,
 			       OchushaApplication *application,
-			       BBSThread *thread)
+			       OchushaBBSThread *thread)
 {
   BBSThreadGUIInfo *thread_info = (BBSThreadGUIInfo *)thread->user_data;
   const gchar *rules;
@@ -1681,7 +1681,7 @@ threadlist_filter_check_thread(ThreadlistFilter *filter,
 	  break;
 
 	case THREADLIST_FILTER_RULE_SHOW_DAT_DROPPED_THREAD:
-	  if (thread->flags & BBS_THREAD_DAT_DROPPED)
+	  if (thread->flags & OCHUSHA_BBS_THREAD_DAT_DROPPED)
 	    {
 #if DEBUG_GUI_MOST
 	      fprintf(stderr, "TRUE: show thread whose dat was dropped.\n");
