@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: threadlist_view.c,v 1.4 2003/05/11 23:04:36 fuyu Exp $
  */
 
 #include "config.h"
@@ -31,6 +31,8 @@
 #include "ochusha.h"
 #include "ochusha_ui.h"
 
+#include "ochusha_bbs_thread.h"
+
 #include "threadlist_view.h"
 
 #include "marshal.h"
@@ -43,6 +45,7 @@
 #include <stdio.h>
 #endif
 #include <stdlib.h>
+#include <string.h>
 
 
 static void threadlist_view_class_init(ThreadlistViewClass *klass);
@@ -54,9 +57,23 @@ static void threadlist_view_init(ThreadlistView *view);
 static void threadlist_view_finalize(GObject *object);
 static void threadlist_view_destroy(GtkObject *object);
 
+static gboolean threadlist_view_title_not_equals(GtkTreeModel *model,
+						 gint column,
+						 const gchar *key,
+						 GtkTreeIter *iter,
+						 gpointer search_data);
+
 static gboolean threadlist_view_move_cursor(ThreadlistView *view,
 					    GtkMovementStep step,
 					    gint count);
+#if 0
+/*
+ * TODO: Emacs^Säݤ񤤤¸ˤϡ롼Ǽ
+ *       뤷ʤäݤʡ
+ */
+static gboolean threadlist_view_search_title(ThreadlistView *view,
+					     int direction);
+#endif
 
 static void threadlist_view_do_on_selection(ThreadlistView *view,
 					    gint what_to_do);
@@ -159,6 +176,7 @@ enum {
   TREE_VIEW_MOVE_CURSOR_SIGNAL,
   TREE_VIEW_UNSELECT_ALL_SIGNAL,
   TREE_VIEW_SELECT_CURSOR_ROW_SIGNAL,
+  TREE_VIEW_START_INTERACTIVE_SEARCH_SIGNAL,
   TREE_VIEW_LAST_SIGNAL
 };
 static gint tree_view_signals[TREE_VIEW_LAST_SIGNAL] = { 0, 0, 0 };
@@ -176,6 +194,16 @@ enum {
 static GtkItemFactory *popup_menu_item_factory = NULL;
 
 
+#if 0	/* TODO: 롼Ǽ뤷ʤäݤ */
+enum {
+  THREADLIST_SEARCH_FORWARD,
+  THREADLIST_SEARCH_BACKWARD,
+  THREADLIST_SEARCH_REGEXP_FORWARD,
+  THREADLIST_SEARCH_REGEXP_BACKWARD,
+};
+#endif
+
+
 static void
 threadlist_view_class_init(ThreadlistViewClass *klass)
 {
@@ -330,11 +358,23 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 		 G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 		 G_STRUCT_OFFSET(ThreadlistViewClass, move_cursor),
 		 NULL, NULL,
-		 ochusha_marshal_VOID__ENUM_INT,
+		 ochusha_marshal_BOOLEAN__ENUM_INT,
 		 G_TYPE_NONE, 2,
 		 GTK_TYPE_MOVEMENT_STEP,
 		 G_TYPE_INT);
 
+#if 0	/* TODO: 롼Ǽ뤷ʤäݤ */
+  threadlist_view_signals[SEARCH_TITLE_SIGNAL] =
+    g_signal_new("search_title",
+		 G_TYPE_FROM_CLASS(klass),
+		 G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
+		 G_STRUCT_OFFSET(ThreadlistViewClass, search_title),
+		 NULL, NULL,
+		 ochusha_marshal_VOID__INT,
+		 G_TYPE_NONE, 1,
+		 G_TYPE_INT);
+#endif
+
   threadlist_view_signals[DO_ON_SELECTION_SIGNAL] =
     g_signal_new("do_on_selection",
 		 G_TYPE_FROM_CLASS(klass),
@@ -360,19 +400,14 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
     g_signal_lookup("unselect_all", GTK_TYPE_TREE_VIEW);
   tree_view_signals[TREE_VIEW_SELECT_CURSOR_ROW_SIGNAL] =
     g_signal_lookup("select_cursor_row", GTK_TYPE_TREE_VIEW);
+  tree_view_signals[TREE_VIEW_START_INTERACTIVE_SEARCH_SIGNAL] =
+    g_signal_lookup("start_interactive_search", GTK_TYPE_TREE_VIEW);
 
   /* Key bindings */
-#if 0
-  gtk_binding_entry_add_signal(binding_set, GDK_o, 0, "open_selection", 1,
-			       G_TYPE_BOOLEAN, FALSE);
-  gtk_binding_entry_add_signal(binding_set, GDK_t, 0, "open_selection", 1,
-			       G_TYPE_BOOLEAN, TRUE);
-#else
   gtk_binding_entry_add_signal(binding_set, GDK_o, 0, "do_on_selection", 1,
 			       G_TYPE_INT, POPUP_MENU_OPEN_SELECTION);
   gtk_binding_entry_add_signal(binding_set, GDK_t, 0, "do_on_selection", 1,
 			       G_TYPE_INT, POPUP_MENU_OPEN_SELECTION_IN_TAB);
-#endif
   gtk_binding_entry_add_signal(binding_set, GDK_asterisk, 0,
 			       "do_on_thread_at_cursor", 1,
 			       G_TYPE_INT, MARK_THREAD);
@@ -402,6 +437,15 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 			       G_TYPE_ENUM, GTK_MOVEMENT_PAGES,
 			       G_TYPE_INT, -1);
 
+#if 0	/* TODO: 롼Ǽ뤷ʤäݤ */
+  gtk_binding_entry_add_signal(binding_set, GDK_s, GDK_CONTROL_MASK,
+			       "search_title", 1,
+			       G_TYPE_ENUM, THREADLIST_SEARCH_FORWARD);
+  gtk_binding_entry_add_signal(binding_set, GDK_r, GDK_CONTROL_MASK,
+			       "search_title", 1,
+			       G_TYPE_ENUM, THREADLIST_SEARCH_BACKWARD);
+#endif
+
   klass->open_view = NULL;
 
   klass->thread_mouse_over = NULL;
@@ -414,6 +458,9 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
   klass->back_view = NULL;
 
   klass->move_cursor = threadlist_view_move_cursor;
+#if 0	/* TODO: 롼Ǽ뤷ʤäݤ */
+  klass->search_title = threadlist_view_search_title;
+#endif
 
   klass->do_on_selection = threadlist_view_do_on_selection;
   klass->do_on_thread_at_cursor = threadlist_view_do_on_thread_at_cursor;
@@ -540,6 +587,12 @@ threadlist_view_init(ThreadlistView *view)
 					  NULL, NULL);
   gtk_tree_view_append_column(view->view, column);
   view->rank_diff_column = column;
+
+  gtk_tree_view_set_search_column(view->view, THREADLIST_TITLE);
+  gtk_tree_view_set_search_equal_func(view->view,
+				      threadlist_view_title_not_equals,
+				      NULL, NULL);
+  gtk_tree_view_set_enable_search(view->view, TRUE);
 }
 
 
@@ -554,8 +607,12 @@ threadlist_view_finalize(GObject *object)
   fprintf(stderr, "threadlist_view_finalize: model->ref_count=%d\n",
 	  G_OBJECT(view->model)->ref_count);
 #endif
-  g_object_unref(G_OBJECT(view->model));
-
+  if (view->model != NULL)
+    {
+      GObject *model = G_OBJECT(view->model);
+      view->model = NULL;
+      g_object_unref(model);
+    }
 
   if (G_OBJECT_CLASS(parent_class)->finalize)
     (*G_OBJECT_CLASS(parent_class)->finalize)(object);
@@ -575,6 +632,64 @@ threadlist_view_destroy(GtkObject *object)
 }
 
 
+static gboolean
+threadlist_view_title_not_equals(GtkTreeModel *model, gint column,
+				 const gchar *key, GtkTreeIter *iter,
+				 gpointer search_data)
+{
+  const gchar *title;
+  gchar *normalized_key;
+  gchar *case_normalized_key;
+  gchar *normalized_title;
+  gchar *case_normalized_title;
+  gboolean result;
+#if DEBUG_SEARCH
+  char *native_string;
+#endif
+  /* XXX */
+#if DEBUG_SEARCH
+  if (key != NULL)
+    {
+      native_string = convert_string(utf8_to_native, key, -1);
+      fprintf(stderr, "threadlist_view_title_not_equals(): column=%d, key=\"%s\":",
+	      column, key);
+      free(native_string);
+    }
+#endif
+  if (key == NULL)
+    return FALSE;
+
+  gtk_tree_model_get(model, iter, THREADLIST_TITLE, &title, -1);
+#if DEBUG_SEARCH
+  if (title != NULL)
+    {
+      native_string = convert_string(utf8_to_native, title, -1);
+      fprintf(stderr, " title at iter=\"%s\"\n", native_string);
+      free(native_string);
+    }
+  else
+    fprintf(stderr, " title at iter=NULL\n");
+#endif
+  if (title == NULL)
+    return FALSE;
+
+  normalized_key = g_utf8_normalize(key, -1, G_NORMALIZE_ALL);
+  case_normalized_key = g_utf8_casefold(normalized_key, -1);
+
+  normalized_title = g_utf8_normalize(title, -1, G_NORMALIZE_ALL);
+  case_normalized_title = g_utf8_casefold(normalized_title, -1);
+
+  result = (strstr(case_normalized_title, case_normalized_key) == NULL);
+
+  g_free(normalized_key);
+  g_free(case_normalized_key);
+  g_free(normalized_title);
+  g_free(case_normalized_title);
+
+  return result;
+}
+
+
 static gboolean
 threadlist_view_move_cursor(ThreadlistView *view, GtkMovementStep step,
 			    gint count)
@@ -590,6 +705,31 @@ threadlist_view_move_cursor(ThreadlistView *view, GtkMovementStep step,
 }
 
 
+gboolean
+threadlist_view_start_interactive_search(ThreadlistView *view)
+{
+  gboolean result;
+  g_return_val_if_fail(IS_THREADLIST_VIEW(view) && view->view != NULL, FALSE);
+
+  gtk_widget_grab_focus(GTK_WIDGET(view->view));
+
+  g_signal_emit(G_OBJECT(view->view),
+		tree_view_signals[TREE_VIEW_START_INTERACTIVE_SEARCH_SIGNAL],
+		0,
+		&result);
+
+  return result;
+}
+
+
+#if 0	/* TODO: 롼Ǽ뤷ʤäݤ */
+static gboolean
+threadlist_view_search_title(ThreadlistView *view, int direction)
+{
+}
+#endif
+
+
 typedef struct _DoOnSelectionArgs
 {
   ThreadlistView *view;
@@ -601,7 +741,7 @@ static void
 do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 		       GtkTreeIter *iter, DoOnSelectionArgs *args)
 {
-  BBSThread *thread;
+  OchushaBBSThread *thread;
   gint what_to_do = args->what_to_do;
 
   gtk_tree_model_get(model, iter,
@@ -787,7 +927,7 @@ tree_view_motion_notify_event_cb(GtkWidget *widget, GdkEventMotion *event,
 
   if (view->recently_pointed_thread != data)
     {
-      BBSThread *thread = (BBSThread *)data;
+      OchushaBBSThread *thread = (OchushaBBSThread *)data;
 
       if (view->recently_pointed_thread != NULL)
 	g_signal_emit(G_OBJECT(view),
@@ -907,7 +1047,7 @@ tree_view_button_release_event_cb(GtkWidget *widget, GdkEventButton *event,
 
 static void
 set_thread_values(ThreadlistView *view, GtkListStore *store,
-		  int rank, BBSThread *thread)
+		  int rank, OchushaBBSThread *thread)
 {
   ThreadlistInfo *info = thread->user_data;
 
@@ -1077,7 +1217,7 @@ threadlist_view_open(ThreadlistView *view, ThreadlistInfoNewFunc *factory)
 			     G_TYPE_INT,	/* number of responses read */
 			     G_TYPE_INT,	/* number of responses read */
 			     G_TYPE_INT,	/* rank difference */
-			     G_TYPE_POINTER);	/* data (BBSThread *) */
+			     G_TYPE_POINTER);	/* data (OchushaBBSThread *) */
 
   gtk_tree_view_set_model(view->view, GTK_TREE_MODEL(store));
   view->model = GTK_TREE_MODEL(store);
@@ -1099,7 +1239,7 @@ threadlist_view_close(ThreadlistView *view)
 
 
 void
-threadlist_view_append_thread(ThreadlistView *view, BBSThread *thread,
+threadlist_view_append_thread(ThreadlistView *view, OchushaBBSThread *thread,
 			      gint rank)
 {
   ThreadlistInfo *info = thread->user_data;
@@ -1123,7 +1263,7 @@ threadlist_view_append_thread(ThreadlistView *view, BBSThread *thread,
 
 
 void
-threadlist_view_update_thread(ThreadlistView *view, BBSThread *thread)
+threadlist_view_update_thread(ThreadlistView *view, OchushaBBSThread *thread)
 {
   gpointer data = NULL;
   ThreadlistInfo *info;
@@ -1162,7 +1302,8 @@ threadlist_view_update_thread(ThreadlistView *view, BBSThread *thread)
 
 
 void
-threadlist_view_scroll_to_thread(ThreadlistView *view, BBSThread *thread)
+threadlist_view_scroll_to_thread(ThreadlistView *view,
+				 OchushaBBSThread *thread)
 {
   gpointer data = NULL;
   GtkTreePath *path;
