@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: threadlist_view.h,v 1.2 2003/05/11 20:55:12 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -72,9 +72,9 @@ struct _ThreadlistView
 
   gint number_of_threads;
 
-  ThreadlistInfo *(*threadlist_info_new)(BBSThread *thread);
+  ThreadlistInfo *(*threadlist_info_new)(OchushaBBSThread *thread);
 
-  BBSThread *recently_pointed_thread;
+  OchushaBBSThread *recently_pointed_thread;
 
   gboolean model_is_opened;
 };
@@ -84,19 +84,24 @@ struct _ThreadlistViewClass
 {
   GtkScrolledWindowClass parent_class;
 
-  void (*open_view)(ThreadlistView *threadlist_view, BBSThread *thread,
+  void (*open_view)(ThreadlistView *threadlist_view, OchushaBBSThread *thread,
 		    gboolean in_tab);
 
   void (*thread_mouse_over)(ThreadlistView *threadlist_view,
-			    BBSThread *thread);
-  void (*thread_mouse_out)(ThreadlistView *threadlist_view, BBSThread *thread);
+			    OchushaBBSThread *thread);
+  void (*thread_mouse_out)(ThreadlistView *threadlist_view,
+			   OchushaBBSThread *thread);
 
-  void (*toggle_mark)(ThreadlistView *threadlist_view, BBSThread *thread);
-  void (*toggle_hide)(ThreadlistView *threadlist_view, BBSThread *thread);
-  void (*mark_thread)(ThreadlistView *threadlist_view, BBSThread *thread,
-		      gboolean do_mark);
-  gboolean (*advance_view)(ThreadlistView *threadlist_view, BBSThread *thread);
-  gboolean (*back_view)(ThreadlistView *threadlist_view, BBSThread *thread);
+  void (*toggle_mark)(ThreadlistView *threadlist_view,
+		      OchushaBBSThread *thread);
+  void (*toggle_hide)(ThreadlistView *threadlist_view,
+		      OchushaBBSThread *thread);
+  void (*mark_thread)(ThreadlistView *threadlist_view,
+		      OchushaBBSThread *thread, gboolean do_mark);
+  gboolean (*advance_view)(ThreadlistView *threadlist_view,
+			   OchushaBBSThread *thread);
+  gboolean (*back_view)(ThreadlistView *threadlist_view,
+			OchushaBBSThread *thread);
 
   gboolean (*move_cursor)(ThreadlistView *threadlist_view,
 			  GtkMovementStep step, gint count);
@@ -132,16 +137,19 @@ GType threadlist_view_get_type(void);
 GtkWidget *threadlist_view_new(void);
 
 
-typedef ThreadlistInfo *ThreadlistInfoNewFunc(BBSThread *thread);
+typedef ThreadlistInfo *ThreadlistInfoNewFunc(OchushaBBSThread *thread);
 
 gboolean threadlist_view_open(ThreadlistView *view,
 			      ThreadlistInfoNewFunc *factory);
 void threadlist_view_close(ThreadlistView *view);
-void threadlist_view_append_thread(ThreadlistView *view, BBSThread *thread,
-				   gint rank);
-void threadlist_view_update_thread(ThreadlistView *view, BBSThread *thread);
-void threadlist_view_scroll_to_thread(ThreadlistView *view, BBSThread *thread);
+void threadlist_view_append_thread(ThreadlistView *view,
+				   OchushaBBSThread *thread, gint rank);
+void threadlist_view_update_thread(ThreadlistView *view,
+				   OchushaBBSThread *thread);
+void threadlist_view_scroll_to_thread(ThreadlistView *view,
+				      OchushaBBSThread *thread);
 
+gboolean threadlist_view_start_interactive_search(ThreadlistView *view);
 
 #ifdef __cplusplus
 } // extern "C"
