@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: htmlutils.c,v 1.1.1.1 2003/05/10 16:34:27 fuyu Exp $
  */
 
 #include "config.h"
@@ -1145,97 +1145,3 @@ simple_string_canon(const char *src, int len, iconv_t converter)
 
   return context.buffer;
 }
-
-
-gchar *
-escape_for_sgml(const gchar *src)
-{
-  gchar default_buffer[DEFAULT_BUFFER_SIZE];
-  const gchar *cur_src_pos = src;
-  gchar *cur_buffer = default_buffer;
-  gchar *cur_buf_pos = default_buffer;
-  size_t cur_buf_len = DEFAULT_BUFFER_SIZE;
-  size_t cur_result_len = 0;
-  size_t len;
-  if (src == NULL)
-    return NULL;
-
-  cur_buf_pos[0] = '\0';	/* ʤ⡩ */
-
-  while (*cur_src_pos != '\0')
-    {
-      gchar *tmp_pos = strpbrk(cur_src_pos, "&<>");
-      if (tmp_pos == NULL)
-	len = strlen(cur_src_pos);
-      else
-	len = tmp_pos - cur_src_pos + 5;	/* ¿ˡġ */
-
-      while (cur_buf_len - cur_result_len <= len)
-	{
-	  gchar *new_buf;
-	  if (cur_buffer == default_buffer)
-	    {
-	      new_buf = (gchar *)malloc(cur_buf_len * 2);
-	      if (new_buf == NULL)
-		return NULL;	/* Out of memory */
-	      strcpy(new_buf, cur_buffer);
-	      cur_buf_len *= 2;
-	      cur_buffer = new_buf;
-	    }
-	  else
-	    {
-	      new_buf = (gchar *)realloc(cur_buffer, cur_buf_len * 2);
-	      if (new_buf == NULL)
-		return cur_buffer;	/* Out of memory */
-	    }
-	  cur_buf_len *= 2;
-	  cur_buffer = new_buf;
-	  cur_buf_pos = cur_buffer + cur_result_len;
-	}
-
-      if (tmp_pos != NULL)
-	len -= 5;	/* ᤹ */
-
-      memcpy(cur_buf_pos, cur_src_pos, len);
-      cur_result_len += len;
-      cur_buf_pos += len;
-      cur_src_pos += len;
-
-      if (tmp_pos != NULL)
-	{
-	  switch (*tmp_pos)
-	    {
-	    case '&':
-	      strcpy(cur_buf_pos, "&amp;");
-	      cur_result_len += 5;
-	      cur_buf_pos += 5;
-	      cur_src_pos++;
-	      break;
-
-	    case '<':
-	      strcpy(cur_buf_pos, "&lt;");
-	      cur_result_len += 4;
-	      cur_buf_pos += 4;
-	      cur_src_pos++;
-	      break;
-
-	    case '>':
-	      strcpy(cur_buf_pos, "&gt;");
-	      cur_result_len += 4;
-	      cur_buf_pos += 4;
-	      cur_src_pos++;
-	      break;
-
-	    default:
-	      abort();	/* ꤨʤ */
-	    }
-	}
-    }
-
-  *cur_buf_pos++ = '\0';
-  cur_result_len++;
-  if (cur_buffer == default_buffer)
-    return strdup(cur_buffer);
-
-  return (gchar *)realloc(cur_buffer, cur_result_len);
-}
