@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: network.c,v 1.1.1.1 2003/05/10 16:34:28 fuyu Exp $
  */
 
 #include "ochusha.h"
@@ -69,12 +69,13 @@ struct timespec polling_interval =
 
 
 static int read_cache_to_buffer(OchushaConfig *conf, const char *url,
-				AsyncBuffer *buffer);
+				OchushaAsyncBuffer *buffer);
 static void write_buffer_to_cache(OchushaConfig *conf, const char *url,
-				  AsyncBuffer *buffer);
+				  OchushaAsyncBuffer *buffer);
 static void setup_common_request_headers(OchushaConfig *conf,
 					 ghttp_request *request);
-static gboolean http_read_from_url(OchushaConfig *conf, AsyncBuffer *buffer,
+static gboolean http_read_from_url(OchushaConfig *conf,
+				   OchushaAsyncBuffer *buffer,
 				   const char *url, const char *last_modified,
 				   OchushaNetworkCallbacks *callbacks,
 				   gpointer callback_data);
@@ -82,14 +83,15 @@ static int get_content_length(ghttp_request *request);
 static void try_update(WorkerThread *employee, gpointer args);
 static void refresh_after_read(WorkerThread *employee, gpointer args);
 static void force_read(WorkerThread *employee, gpointer args);
-static AsyncBuffer *employ_networking_thread(OchushaConfig *conf,
+static OchushaAsyncBuffer *employ_networking_thread(OchushaConfig *conf,
 					     const char *url,
 					     const char *last_modified,
 					     JobFunc *job_function,
 					     OchushaNetworkCallbacks *callbacks,
 					     gpointer callback_data);
-static void munmap_when_finished(AsyncBuffer *buffer, gpointer user_data);
-static AsyncBuffer *get_mmapped_buffer(int fd);
+static void munmap_when_finished(OchushaAsyncBuffer *buffer,
+				 gpointer user_data);
+static OchushaAsyncBuffer *get_mmapped_buffer(int fd);
 
 
 static const char http_hdr_Cookie[] = "Cookie";
@@ -98,10 +100,10 @@ static const char http_hdr_Set_Cookie2[] = "Set-Cookie2";
 
 static int
 read_cache_to_buffer(OchushaConfig *conf, const char *url,
-		     AsyncBuffer *buffer)
+		     OchushaAsyncBuffer *buffer)
 {
   int len;
-  int fd = ochusha_cache_open_file(conf, url, O_RDONLY);
+  int fd = ochusha_config_cache_open_file(conf, url, O_RDONLY);
 
   if (fd == -1)
     return 0;	/* åʤξ */
@@ -109,11 +111,12 @@ read_cache_to_buffer(OchushaConfig *conf, const char *url,
   /* å夢ꡣ*/
   len = lseek(fd, 0, SEEK_END);
   lseek(fd, 0, SEEK_SET);
-  if (async_buffer_resize(buffer, len, "network.c: read_cache_to_buffer"))
+  if (ochusha_async_buffer_resize(buffer, len,
+				  "network.c: read_cache_to_buffer"))
     {
       len = read(fd, (void *)buffer->buffer, len);
-      if (!async_buffer_update_length(buffer, len,
-				     "network.c: read_cache_to_buffer"))
+      if (!ochusha_async_buffer_update_length(buffer, len,
+				"network.c: read_cache_to_buffer"))
 	{
 #if DEBUG_ASYNC_BUFFER_MOST
 	  fprintf(stderr, "read_cache_to_buffer: buffer may have been terminated.\n");
@@ -136,10 +139,10 @@ read_cache_to_buffer(OchushaConfig *conf, const char *url,
 
 static void
 write_buffer_to_cache(OchushaConfig *conf, const char *url,
-		      AsyncBuffer *buffer)
+		      OchushaAsyncBuffer *buffer)
 {
-  int fd = ochusha_cache_open_file(conf, url,
-				   O_WRONLY | O_TRUNC | O_CREAT);
+  int fd = ochusha_config_cache_open_file(conf, url,
+					  O_WRONLY | O_TRUNC | O_CREAT);
   if (fd >= 0)
     {
       ssize_t len = write(fd, (void *)buffer->buffer, buffer->length);
@@ -193,8 +196,8 @@ get_content_encoding_type(ghttp_request *request)
 
 
 static gboolean
-http_read_from_url(OchushaConfig *conf, AsyncBuffer *buffer, const char *url,
-		   const char *last_modified,
+http_read_from_url(OchushaConfig *conf, OchushaAsyncBuffer *buffer,
+		   const char *url, const char *last_modified,
 		   OchushaNetworkCallbacks *callbacks, gpointer callback_data)
 {
 #if DEBUG_NETWORK
@@ -215,7 +218,7 @@ http_read_from_url(OchushaConfig *conf, AsyncBuffer *buffer, const char *url,
   ghttp_set_header(request, http_hdr_Accept_Encoding, "gzip");
   if (last_modified != NULL)
     {
-      int fd = ochusha_cache_open_file(conf, url, O_RDONLY);
+      int fd = ochusha_config_cache_open_file(conf, url, O_RDONLY);
       if (fd != -1)
 	{
 	  ghttp_set_header(request, http_hdr_If_Modified_Since, last_modified);
@@ -248,7 +251,8 @@ http_read_from_url(OchushaConfig *conf, AsyncBuffer *buffer, const char *url,
       sock_fd = ghttp_get_socket(request);
       fprintf(stderr, "1: sock_fd=%d state=%d\n", sock_fd, state);
 #endif
-      if (!async_buffer_check_active(buffer, "network.c: http_read_from_url"))
+      if (!ochusha_async_buffer_check_active(buffer,
+					     "network.c: http_read_from_url"))
 	state = ghttp_error;
       if (state == ghttp_error || state == ghttp_done)
 	break;
@@ -398,8 +402,8 @@ http_read_from_url(OchushaConfig *conf, AsyncBuffer *buffer, const char *url,
 		  break;
 		}
 	    }
-	  else if (!async_buffer_append_data(buffer, body, body_len,
-					     "network.c: http_read_from_url"))
+	  else if (!ochusha_async_buffer_append_data(buffer, body, body_len,
+					"network.c: http_read_from_url"))
 	    {	/* content_encoding == STANDARD_ENCODING */
 #if DEBUG_ASYNC_BUFFER_MOST
 	      fprintf(stderr, "http_read_from_url: buffer may have been terminated.\n");
@@ -462,7 +466,7 @@ http_read_from_url(OchushaConfig *conf, AsyncBuffer *buffer, const char *url,
 typedef struct _NetworkJobArgs
 {
   OchushaConfig *conf;
-  AsyncBuffer *buffer;
+  OchushaAsyncBuffer *buffer;
   char *url;
   char *last_modified;
   OchushaNetworkCallbacks *callbacks;
@@ -499,13 +503,13 @@ try_update(WorkerThread *employee, gpointer args)
 {
   NetworkJobArgs *job_args = (NetworkJobArgs *)args;
   OchushaConfig *conf = job_args->conf;
-  AsyncBuffer *buffer = job_args->buffer;
+  OchushaAsyncBuffer *buffer = job_args->buffer;
   char *url = job_args->url;
   OchushaNetworkStatus *buf_status = (OchushaNetworkStatus *)buffer->user_data;
   int len;
   ContentEncodingType content_encoding = UNKNOWN_ENCODING;
 
-  if (!async_buffer_active_ref(buffer, "network.c: try_update"))
+  if (!ochusha_async_buffer_active_ref(buffer, "network.c: try_update"))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -516,7 +520,7 @@ try_update(WorkerThread *employee, gpointer args)
 	  && job_args->callbacks->access_failed != NULL)
 	(*job_args->callbacks->access_failed)(job_args->callback_data);
 
-      async_buffer_fix(buffer, "network.c: try_update");
+      ochusha_async_buffer_fix(buffer, "network.c: try_update");
       g_object_unref(G_OBJECT(buffer));
       free(url);
       free(args);
@@ -583,7 +587,8 @@ try_update(WorkerThread *employee, gpointer args)
       while (TRUE)
 	{
 	  state = ghttp_process(request);
-	  if (!async_buffer_check_active(buffer, "network.c: try_update"))
+	  if (!ochusha_async_buffer_check_active(buffer,
+						 "network.c: try_update"))
 	    state = ghttp_error;
 	  if (state == ghttp_error || state == ghttp_done)
 	    break;
@@ -687,12 +692,12 @@ try_update(WorkerThread *employee, gpointer args)
 	   * Хåեɤ߹ߡå夬ɤǧ
 	   *
 	   * ägzipʾбݤʤΤǡ
-	   * ޤAsyncBufferͭǡCACHE_COMPARE_SIZEʬ
+	   * ޤOchushaAsyncBufferͭǡCACHE_COMPARE_SIZEʬ
 	   * (å夵Ƥǡ)Хåե˥ԡ
-	   * AsyncBufferͭǡĹCACHE_COMPARE_SIZEʬ餷Ƥ
+	   * OchushaAsyncBufferͭǡĹCACHE_COMPARE_SIZEʬ餷Ƥ
 	   * ޤGzipBuffer٤餫GzipBufferAPI
 	   * ɲä٤
-	   * AsyncBufferconsumer¦read-onlyǡХåեΰ輫Τ
+	   * OchushaAsyncBufferconsumer¦read-onlyǡХåեΰ輫Τ
 	   * ͭʤΤɤޤƤʤޤå夬ʾ
 	   * Ʊǡ񤭤å夬Ȥ
 	   * äˤϡ̵Τǰʥǡ
@@ -702,8 +707,8 @@ try_update(WorkerThread *employee, gpointer args)
 	  memcpy(cache_compare_buffer, (char *)buffer->buffer + offset,
 		 CACHE_COMPARE_SIZE);
 
-	  if (!async_buffer_update_length(buffer, offset,
-					  "network.c: http_read_from_url"))
+	  if (!ochusha_async_buffer_update_length(buffer, offset,
+					"network.c: http_read_from_url"))
 	    {
 #if DEBUG_ASYNC_BUFFER_MOST
 	      fprintf(stderr, "http_read_from_url: buffer may have been terminated.\n");
@@ -812,8 +817,9 @@ try_update(WorkerThread *employee, gpointer args)
 			  break;
 			}
 		    }
-		  else if (!async_buffer_append_data(buffer, body, body_len,
-						     "network.c: try_update"))
+		  else if (!ochusha_async_buffer_append_data(buffer, body,
+						body_len,
+						"network.c: try_update"))
 		    {	/* content_encoding == STANDARD_ENCODING */
 #if DEBUG_ASYNC_BUFFER_MOST
 		      fprintf(stderr, "buffer may have been terminated.\n");
@@ -896,8 +902,8 @@ try_update(WorkerThread *employee, gpointer args)
 	    fprintf(stderr, "Cannot access network?\n");
 #endif
 	  buf_status->state = OCHUSHA_CACHE_IS_OK;
-	  if (!async_buffer_update_length(buffer, len,
-					  "network.c: try_update"))
+	  if (!ochusha_async_buffer_update_length(buffer, len,
+						  "network.c: try_update"))
 	    {
 #if DEBUG_ASYNC_BUFFER_MOST
 	      fprintf(stderr, "buffer has been terminated.\n");
@@ -919,7 +925,8 @@ try_update(WorkerThread *employee, gpointer args)
 
       buf_status->state = OCHUSHA_CACHE_IS_DIRTY;
       ghttp_request_destroy(request);
-      if (!async_buffer_update_length(buffer, 0, "network.c: try_update"))
+      if (!ochusha_async_buffer_update_length(buffer, 0,
+					      "network.c: try_update"))
 	{
 #if DEBUG_ASYNC_BUFFER_MOST
 	  fprintf(stderr, "buffer has been terminated.\n");
@@ -958,8 +965,8 @@ try_update(WorkerThread *employee, gpointer args)
     (*job_args->callbacks->access_failed)(job_args->callback_data);
 
  read_done:
-  async_buffer_fix(buffer, "network.c: try_update");
-  async_buffer_active_unref(buffer, "network.c: try_update");
+  ochusha_async_buffer_fix(buffer, "network.c: try_update");
+  ochusha_async_buffer_active_unref(buffer, "network.c: try_update");
   g_object_unref(G_OBJECT(buffer));
   free(url);
   if (job_args->last_modified != NULL)
@@ -973,11 +980,12 @@ refresh_after_read(WorkerThread *employee, gpointer args)
 {
   NetworkJobArgs *job_args = (NetworkJobArgs *)args;
   OchushaConfig *conf = job_args->conf;
-  AsyncBuffer *buffer = job_args->buffer;
+  OchushaAsyncBuffer *buffer = job_args->buffer;
   char *url = job_args->url;
   OchushaNetworkStatus *status = (OchushaNetworkStatus *)buffer->user_data;
 
-  if (!async_buffer_active_ref(buffer, "network.c: refresh_after_read"))
+  if (!ochusha_async_buffer_active_ref(buffer,
+				       "network.c: refresh_after_read"))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -1031,10 +1039,10 @@ refresh_after_read(WorkerThread *employee, gpointer args)
 	}
     }
 
-  async_buffer_active_unref(buffer, "network.c: refresh_after_read");
+  ochusha_async_buffer_active_unref(buffer, "network.c: refresh_after_read");
 
  error_exit:
-  async_buffer_fix(buffer, "network.c: refresh_after_read");
+  ochusha_async_buffer_fix(buffer, "network.c: refresh_after_read");
   g_object_unref(G_OBJECT(buffer));
   free(url);
   free(args);
@@ -1045,10 +1053,10 @@ static void
 force_read(WorkerThread *employee, gpointer args)
 {
   NetworkJobArgs *job_args = (NetworkJobArgs *)args;
-  AsyncBuffer *buffer = job_args->buffer;
+  OchushaAsyncBuffer *buffer = job_args->buffer;
   OchushaNetworkStatus *status = (OchushaNetworkStatus *)buffer->user_data;
 
-  if (!async_buffer_active_ref(buffer, "network.c: force_read"))
+  if (!ochusha_async_buffer_active_ref(buffer, "network.c: force_read"))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -1081,10 +1089,10 @@ force_read(WorkerThread *employee, gpointer args)
 #endif
     }
 
-  async_buffer_active_unref(buffer, "network.c: force_read");
+  ochusha_async_buffer_active_unref(buffer, "network.c: force_read");
 
  error_exit:
-  async_buffer_fix(buffer, "network.c: force_read");
+  ochusha_async_buffer_fix(buffer, "network.c: force_read");
   g_object_unref(G_OBJECT(buffer));
   free(job_args->url);
   if (job_args->last_modified != NULL)
@@ -1094,7 +1102,7 @@ force_read(WorkerThread *employee, gpointer args)
 
 
 static void
-network_buffer_free(AsyncBuffer *buffer, gpointer user_data)
+network_buffer_free(OchushaAsyncBuffer *buffer, gpointer user_data)
 {
   OchushaNetworkStatus *status = (OchushaNetworkStatus *)user_data;
 #if DEBUG_NETWORK_MOST
@@ -1111,7 +1119,7 @@ network_buffer_free(AsyncBuffer *buffer, gpointer user_data)
 }
 
 
-static AsyncBuffer *
+static OchushaAsyncBuffer *
 employ_networking_thread(OchushaConfig *conf, const char *url,
 			 const char *last_modified,
 			 JobFunc *job_function,
@@ -1122,7 +1130,8 @@ employ_networking_thread(OchushaConfig *conf, const char *url,
   WorkerJob *job;
   OchushaNetworkStatus *status
     = (OchushaNetworkStatus *)calloc(1, sizeof(OchushaNetworkStatus));
-  AsyncBuffer *buffer = async_buffer_new(NULL, 0, status, network_buffer_free);
+  OchushaAsyncBuffer *buffer = ochusha_async_buffer_new(NULL, 0, status,
+							network_buffer_free);
 
 #if DEBUG_NETWORK_MOST
   fprintf(stderr, "employ_networking_thread: url=\"%s\" buffer=0x%x\n",
@@ -1189,7 +1198,7 @@ employ_networking_thread(OchushaConfig *conf, const char *url,
 
 
 static void
-munmap_when_finished(AsyncBuffer *buffer, gpointer user_data)
+munmap_when_finished(OchushaAsyncBuffer *buffer, gpointer user_data)
 {
   munmap((void *)buffer->buffer, buffer->length);
   if (user_data != NULL)
@@ -1200,12 +1209,12 @@ munmap_when_finished(AsyncBuffer *buffer, gpointer user_data)
 }
 
 
-static AsyncBuffer *
+static OchushaAsyncBuffer *
 get_mmapped_buffer(int fd)
 {
   char *buf;
   off_t len;
-  AsyncBuffer *buffer;
+  OchushaAsyncBuffer *buffer;
   OchushaNetworkStatus *status;
 
   if (fd < 0)
@@ -1232,8 +1241,8 @@ get_mmapped_buffer(int fd)
 	  (int)buf);
 #endif
 
-  buffer = async_buffer_new(buf, len, status, munmap_when_finished);
-  if (!async_buffer_fix(buffer, "network.c: get_mmapped_buffer"))
+  buffer = ochusha_async_buffer_new(buf, len, status, munmap_when_finished);
+  if (!ochusha_async_buffer_fix(buffer, "network.c: get_mmapped_buffer"))
     {
 #if DEBUG_ASYNC_BUFFER_MOST
       fprintf(stderr, "buffer has been terminated.\n");
@@ -1270,7 +1279,7 @@ get_mmapped_buffer(int fd)
  * ͥåȥ˥硢̿˼ԤǤĹ0ΥХåե
  * ֤Τա
  */
-AsyncBuffer *
+OchushaAsyncBuffer *
 ochusha_read_from_url(OchushaConfig *conf, const char *url,
 		      const char *last_modified,
 		      OchushaCacheMode mode,
@@ -1293,7 +1302,7 @@ ochusha_read_from_url(OchushaConfig *conf, const char *url,
       || mode == OCHUSHA_CACHE_AS_IS || mode == OCHUSHA_CACHE_ONLY)
     {
       /* å夬ä餽򤽤Τޤ޻Ȥ */
-      int fd = ochusha_cache_open_file(conf, url, O_RDONLY);
+      int fd = ochusha_config_cache_open_file(conf, url, O_RDONLY);
       if (fd >= 0)
 	{
 	  if (callbacks != NULL && callbacks->access_completed != NULL)
@@ -1322,25 +1331,3 @@ ochusha_read_from_url(OchushaConfig *conf, const char *url,
   return employ_networking_thread(conf, url, NULL, force_read,
 				  callbacks, callback_data);
 }
-
-
-/*
- * ochusha_readn_subject_txt
- *
- * boardͿ줿ǼĤsubject.txtХåե֤
- */
-AsyncBuffer *
-ochusha_read_subject_txt(OchushaConfig *conf, BulletinBoard *board,
-			 const char *last_modified,
-			 OchushaNetworkCallbacks *callbacks,
-			 gpointer callback_data)
-{
-  char url[PATH_MAX];
-  int len = snprintf(url, PATH_MAX, "%s" OCHUSHA_SUBJECT_TXT, board->base_url);
-  if (len >= PATH_MAX)
-    return NULL;
-
-  return ochusha_read_from_url(conf, url, last_modified,
-			       OCHUSHA_CACHE_TRY_REFRESH,
-			       callbacks, callback_data);
-}
