@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id$
+ * $Id: utils.h,v 1.1.1.1 2003/05/10 16:34:28 fuyu Exp $
  */
 
 #ifndef _UTILS_H_
@@ -46,10 +46,17 @@ extern iconv_t utf8_to_native;
 void initialize_common_converters(void);
 char *convert_string(iconv_t converter, const char *src, int length);
 
+#if 1	/* to be obsoleted soon */
 char *url_extract_http_server(const char *url);
 char *url_extract_http_root_pathname(const char *url);
 char *url_encode_string(const char *src);
 char *url_decode_string(const char *src);
+#endif
+
+char *ochusha_utils_url_extract_http_server(const char *url);
+char *ochusha_utils_url_extract_http_absolute_path(const char *url);
+char *ochusha_utils_url_encode_string(const char *src);
+char *ochusha_utils_url_decode_string(const char *src);
 
 int mkdir_p(const char *path);
 
